# coding: utf-8

"""
    Account API

    The <b>Account API</b> gives sellers the ability to configure their eBay seller accounts, including the seller's policies (eBay business policies and seller-defined custom policies), opt in and out of eBay seller programs, configure sales tax tables, and get account information.  <br/><br/>For details on the availability of the methods in this API, see <a href=\"/api-docs/sell/account/overview.html#requirements\">Account API requirements and restrictions</a>.  # noqa: E501

    OpenAPI spec version: v1.9.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaymentPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_types': 'list[CategoryType]',
        'deposit': 'Deposit',
        'description': 'str',
        'full_payment_due_in': 'TimeDuration',
        'immediate_pay': 'bool',
        'marketplace_id': 'str',
        'name': 'str',
        'payment_instructions': 'str',
        'payment_methods': 'list[PaymentMethod]',
        'payment_policy_id': 'str'
    }

    attribute_map = {
        'category_types': 'categoryTypes',
        'deposit': 'deposit',
        'description': 'description',
        'full_payment_due_in': 'fullPaymentDueIn',
        'immediate_pay': 'immediatePay',
        'marketplace_id': 'marketplaceId',
        'name': 'name',
        'payment_instructions': 'paymentInstructions',
        'payment_methods': 'paymentMethods',
        'payment_policy_id': 'paymentPolicyId'
    }

    def __init__(self, category_types=None, deposit=None, description=None, full_payment_due_in=None, immediate_pay=None, marketplace_id=None, name=None, payment_instructions=None, payment_methods=None, payment_policy_id=None):  # noqa: E501
        """PaymentPolicy - a model defined in Swagger"""  # noqa: E501
        self._category_types = None
        self._deposit = None
        self._description = None
        self._full_payment_due_in = None
        self._immediate_pay = None
        self._marketplace_id = None
        self._name = None
        self._payment_instructions = None
        self._payment_methods = None
        self._payment_policy_id = None
        self.discriminator = None
        if category_types is not None:
            self.category_types = category_types
        if deposit is not None:
            self.deposit = deposit
        if description is not None:
            self.description = description
        if full_payment_due_in is not None:
            self.full_payment_due_in = full_payment_due_in
        if immediate_pay is not None:
            self.immediate_pay = immediate_pay
        if marketplace_id is not None:
            self.marketplace_id = marketplace_id
        if name is not None:
            self.name = name
        if payment_instructions is not None:
            self.payment_instructions = payment_instructions
        if payment_methods is not None:
            self.payment_methods = payment_methods
        if payment_policy_id is not None:
            self.payment_policy_id = payment_policy_id

    @property
    def category_types(self):
        """Gets the category_types of this PaymentPolicy.  # noqa: E501

        This container indicates whether the fulfillment policy applies to motor vehicle listings, or if it applies to non-motor vehicle listings.  # noqa: E501

        :return: The category_types of this PaymentPolicy.  # noqa: E501
        :rtype: list[CategoryType]
        """
        return self._category_types

    @category_types.setter
    def category_types(self, category_types):
        """Sets the category_types of this PaymentPolicy.

        This container indicates whether the fulfillment policy applies to motor vehicle listings, or if it applies to non-motor vehicle listings.  # noqa: E501

        :param category_types: The category_types of this PaymentPolicy.  # noqa: E501
        :type: list[CategoryType]
        """

        self._category_types = category_types

    @property
    def deposit(self):
        """Gets the deposit of this PaymentPolicy.  # noqa: E501


        :return: The deposit of this PaymentPolicy.  # noqa: E501
        :rtype: Deposit
        """
        return self._deposit

    @deposit.setter
    def deposit(self, deposit):
        """Sets the deposit of this PaymentPolicy.


        :param deposit: The deposit of this PaymentPolicy.  # noqa: E501
        :type: Deposit
        """

        self._deposit = deposit

    @property
    def description(self):
        """Gets the description of this PaymentPolicy.  # noqa: E501

        A seller-defined description of the payment policy. This description is only for the seller's use, and is not exposed on any eBay pages.  <br/><br/><b>Max length</b>: 250  # noqa: E501

        :return: The description of this PaymentPolicy.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentPolicy.

        A seller-defined description of the payment policy. This description is only for the seller's use, and is not exposed on any eBay pages.  <br/><br/><b>Max length</b>: 250  # noqa: E501

        :param description: The description of this PaymentPolicy.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def full_payment_due_in(self):
        """Gets the full_payment_due_in of this PaymentPolicy.  # noqa: E501


        :return: The full_payment_due_in of this PaymentPolicy.  # noqa: E501
        :rtype: TimeDuration
        """
        return self._full_payment_due_in

    @full_payment_due_in.setter
    def full_payment_due_in(self, full_payment_due_in):
        """Sets the full_payment_due_in of this PaymentPolicy.


        :param full_payment_due_in: The full_payment_due_in of this PaymentPolicy.  # noqa: E501
        :type: TimeDuration
        """

        self._full_payment_due_in = full_payment_due_in

    @property
    def immediate_pay(self):
        """Gets the immediate_pay of this PaymentPolicy.  # noqa: E501

        If this field is returned as <code>true</code>, immediate payment is required from the buyer for: <ul><li>A fixed-price item</li><li>An auction item where the buyer uses the 'Buy it Now' option</li><li>A deposit for a motor vehicle listing</li></ul><br />It is possible for the seller to set this field as <code>true</code> in the payment business policy, but it will not apply in some scenarios. For example, immediate payment is not applicable for auction listings that have a winning bidder, for buyer purchases that involve the Best Offer feature, or for transactions that happen offline between the buyer and seller.  # noqa: E501

        :return: The immediate_pay of this PaymentPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._immediate_pay

    @immediate_pay.setter
    def immediate_pay(self, immediate_pay):
        """Sets the immediate_pay of this PaymentPolicy.

        If this field is returned as <code>true</code>, immediate payment is required from the buyer for: <ul><li>A fixed-price item</li><li>An auction item where the buyer uses the 'Buy it Now' option</li><li>A deposit for a motor vehicle listing</li></ul><br />It is possible for the seller to set this field as <code>true</code> in the payment business policy, but it will not apply in some scenarios. For example, immediate payment is not applicable for auction listings that have a winning bidder, for buyer purchases that involve the Best Offer feature, or for transactions that happen offline between the buyer and seller.  # noqa: E501

        :param immediate_pay: The immediate_pay of this PaymentPolicy.  # noqa: E501
        :type: bool
        """

        self._immediate_pay = immediate_pay

    @property
    def marketplace_id(self):
        """Gets the marketplace_id of this PaymentPolicy.  # noqa: E501

        The ID of the eBay marketplace to which the payment business policy applies. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/account/types/ba:MarketplaceIdEnum'>eBay API documentation</a>  # noqa: E501

        :return: The marketplace_id of this PaymentPolicy.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_id

    @marketplace_id.setter
    def marketplace_id(self, marketplace_id):
        """Sets the marketplace_id of this PaymentPolicy.

        The ID of the eBay marketplace to which the payment business policy applies. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/account/types/ba:MarketplaceIdEnum'>eBay API documentation</a>  # noqa: E501

        :param marketplace_id: The marketplace_id of this PaymentPolicy.  # noqa: E501
        :type: str
        """

        self._marketplace_id = marketplace_id

    @property
    def name(self):
        """Gets the name of this PaymentPolicy.  # noqa: E501

        A seller-defined name for this fulfillment policy. Names must be unique for policies assigned to the same marketplace. <br/><br/><b>Max length</b>: 64  # noqa: E501

        :return: The name of this PaymentPolicy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentPolicy.

        A seller-defined name for this fulfillment policy. Names must be unique for policies assigned to the same marketplace. <br/><br/><b>Max length</b>: 64  # noqa: E501

        :param name: The name of this PaymentPolicy.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def payment_instructions(self):
        """Gets the payment_instructions of this PaymentPolicy.  # noqa: E501

        Although this field may be returned for some older payment business policies, payment instructions are no longer supported by payment business policies. If this field is returned, it can be ignored and these payment instructions will not appear in any listings that use the corresponding business policy. <br/><br/><b>Max length</b>: 1000  # noqa: E501

        :return: The payment_instructions of this PaymentPolicy.  # noqa: E501
        :rtype: str
        """
        return self._payment_instructions

    @payment_instructions.setter
    def payment_instructions(self, payment_instructions):
        """Sets the payment_instructions of this PaymentPolicy.

        Although this field may be returned for some older payment business policies, payment instructions are no longer supported by payment business policies. If this field is returned, it can be ignored and these payment instructions will not appear in any listings that use the corresponding business policy. <br/><br/><b>Max length</b>: 1000  # noqa: E501

        :param payment_instructions: The payment_instructions of this PaymentPolicy.  # noqa: E501
        :type: str
        """

        self._payment_instructions = payment_instructions

    @property
    def payment_methods(self):
        """Gets the payment_methods of this PaymentPolicy.  # noqa: E501

        This container is returned to show the payment methods that are accepted for the payment business policy.  <br><br>Sellers do not have to specify any electronic payment methods for listings, so this array will often be returned empty unless the payment business policy is intended for motor vehicle listings or other items in categories where offline payments are required or supported.   # noqa: E501

        :return: The payment_methods of this PaymentPolicy.  # noqa: E501
        :rtype: list[PaymentMethod]
        """
        return self._payment_methods

    @payment_methods.setter
    def payment_methods(self, payment_methods):
        """Sets the payment_methods of this PaymentPolicy.

        This container is returned to show the payment methods that are accepted for the payment business policy.  <br><br>Sellers do not have to specify any electronic payment methods for listings, so this array will often be returned empty unless the payment business policy is intended for motor vehicle listings or other items in categories where offline payments are required or supported.   # noqa: E501

        :param payment_methods: The payment_methods of this PaymentPolicy.  # noqa: E501
        :type: list[PaymentMethod]
        """

        self._payment_methods = payment_methods

    @property
    def payment_policy_id(self):
        """Gets the payment_policy_id of this PaymentPolicy.  # noqa: E501

        A unique eBay-assigned ID for a payment business policy. This ID is generated when the policy is created.  # noqa: E501

        :return: The payment_policy_id of this PaymentPolicy.  # noqa: E501
        :rtype: str
        """
        return self._payment_policy_id

    @payment_policy_id.setter
    def payment_policy_id(self, payment_policy_id):
        """Sets the payment_policy_id of this PaymentPolicy.

        A unique eBay-assigned ID for a payment business policy. This ID is generated when the policy is created.  # noqa: E501

        :param payment_policy_id: The payment_policy_id of this PaymentPolicy.  # noqa: E501
        :type: str
        """

        self._payment_policy_id = payment_policy_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Recommendation API

    The <b>Recommendation API</b> returns information that sellers can use to optimize the configuration of their listings on eBay. <br><br>Currently, the API contains a single method, <b>findListingRecommendations</b>. This method provides information that sellers can use to configure Promoted Listings ad campaigns to maximize the visibility of their items in the eBay marketplace.  # noqa: E501

    OpenAPI spec version: 1.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Ad(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bid_percentages': 'list[BidPercentages]',
        'promote_with_ad': 'str'
    }

    attribute_map = {
        'bid_percentages': 'bidPercentages',
        'promote_with_ad': 'promoteWithAd'
    }

    def __init__(self, bid_percentages=None, promote_with_ad=None):  # noqa: E501
        """Ad - a model defined in Swagger"""  # noqa: E501
        self._bid_percentages = None
        self._promote_with_ad = None
        self.discriminator = None
        if bid_percentages is not None:
            self.bid_percentages = bid_percentages
        if promote_with_ad is not None:
            self.promote_with_ad = promote_with_ad

    @property
    def bid_percentages(self):
        """Gets the bid_percentages of this Ad.  # noqa: E501

        This field returns information that you can use to configure the bidPercentage field in a Promoted Listings campaign. Note: Currently, ITEM and TRENDING are the only supported bid percentage types. The ITEM suggested bid percentages are tailored to each of your items and are designed to help you stay competitive while finding an optimal balance between performance and cost. The recommendations are calculated based on a variety of factors that may include item attributes, seasonality, past performance, and current competition for each of your listings. The TRENDING suggested bid percentages are calculated by reviewing the category level average ad rates in the marketplace. Setting the bidPercentage of your ad campaign based on these rate recommendations will help the items in the campaign be competitive with other items in the marketplace by improving their chances of being displayed more often in the marketplace.  # noqa: E501

        :return: The bid_percentages of this Ad.  # noqa: E501
        :rtype: list[BidPercentages]
        """
        return self._bid_percentages

    @bid_percentages.setter
    def bid_percentages(self, bid_percentages):
        """Sets the bid_percentages of this Ad.

        This field returns information that you can use to configure the bidPercentage field in a Promoted Listings campaign. Note: Currently, ITEM and TRENDING are the only supported bid percentage types. The ITEM suggested bid percentages are tailored to each of your items and are designed to help you stay competitive while finding an optimal balance between performance and cost. The recommendations are calculated based on a variety of factors that may include item attributes, seasonality, past performance, and current competition for each of your listings. The TRENDING suggested bid percentages are calculated by reviewing the category level average ad rates in the marketplace. Setting the bidPercentage of your ad campaign based on these rate recommendations will help the items in the campaign be competitive with other items in the marketplace by improving their chances of being displayed more often in the marketplace.  # noqa: E501

        :param bid_percentages: The bid_percentages of this Ad.  # noqa: E501
        :type: list[BidPercentages]
        """

        self._bid_percentages = bid_percentages

    @property
    def promote_with_ad(self):
        """Gets the promote_with_ad of this Ad.  # noqa: E501

        An enum whose values describe whether or not eBay recommends you place the associated listing in a Promoted Listings ad campaign. IDs deemed RECOMMENDED by eBay are the listings with the highest potential of benefiting from being promoted. The recommendation calculation is based on marketplace trends, like buyer demand and the competition in the item&rsquo;s category. Note: A promoteWithAd value cannot be calculated for listings that are part of Promoted Listings campaigns. Because of this, if you call findListingRecommendations with a specific set of listing IDs, the promoteWithAd field is not returned for any of the listings that are involved in a promotion. However, as long as they are eligible, the trending bidPercentage is returned for all specified listings, even if they are part of an ad campaign. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/recommendation/types/api:PromoteWithAd'>eBay API documentation</a>  # noqa: E501

        :return: The promote_with_ad of this Ad.  # noqa: E501
        :rtype: str
        """
        return self._promote_with_ad

    @promote_with_ad.setter
    def promote_with_ad(self, promote_with_ad):
        """Sets the promote_with_ad of this Ad.

        An enum whose values describe whether or not eBay recommends you place the associated listing in a Promoted Listings ad campaign. IDs deemed RECOMMENDED by eBay are the listings with the highest potential of benefiting from being promoted. The recommendation calculation is based on marketplace trends, like buyer demand and the competition in the item&rsquo;s category. Note: A promoteWithAd value cannot be calculated for listings that are part of Promoted Listings campaigns. Because of this, if you call findListingRecommendations with a specific set of listing IDs, the promoteWithAd field is not returned for any of the listings that are involved in a promotion. However, as long as they are eligible, the trending bidPercentage is returned for all specified listings, even if they are part of an ad campaign. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/recommendation/types/api:PromoteWithAd'>eBay API documentation</a>  # noqa: E501

        :param promote_with_ad: The promote_with_ad of this Ad.  # noqa: E501
        :type: str
        """

        self._promote_with_ad = promote_with_ad

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Ad, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Ad):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Marketing API

    <p>The <i>Marketing API </i> offers two platforms that sellers can use to promote and advertise their products:</p> <ul><li><b>Promoted Listings</b> is an eBay ad service that lets sellers set up <i>ad campaigns </i> for the products they want to promote. eBay displays the ads in search results and in other marketing modules as <b>SPONSORED</b> listings. If an item in a Promoted Listings campaign sells, the seller is assessed a Promoted Listings fee, which is a seller-specified percentage applied to the sales price. For complete details, refer to the <a href=\"/api-docs/sell/static/marketing/pl-landing.html\">Promoted Listings playbook</a>.</li><li><b>Promotions Manager</b> gives sellers a way to offer discounts on specific items as a way to attract buyers to their inventory. Sellers can set up discounts (such as \"20% off\" and other types of offers) on specific items or on an entire customer order. To further attract buyers, eBay prominently displays promotion <i>teasers</i> throughout buyer flows. For complete details, see <a href=\"/api-docs/sell/static/marketing/promotions-manager.html\">Promotions Manager</a>.</li></ul>  <p><b>Marketing reports</b>, on both the Promoted Listings and Promotions Manager platforms, give sellers information that shows the effectiveness of their marketing strategies. The data gives sellers the ability to review and fine tune their marketing efforts.</p> <p class=\"tablenote\"><b>Important!</b> Sellers must have an active eBay Store subscription, and they must accept the <b>Terms and Conditions</b> before they can make requests to these APIs in the Production environment. There are also site-specific listings requirements and restrictions associated with these marketing tools, as listed in the \"requirements and restrictions\" sections for <a href=\"/api-docs/sell/marketing/static/overview.html#PL-requirements\">Promoted Listings</a> and <a href=\"/api-docs/sell/marketing/static/overview.html#PM-requirements\">Promotions Manager</a>.</p> <p>The table below lists all the Marketing API calls grouped by resource.</p>  # noqa: E501

    OpenAPI spec version: v1.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateNegativeKeywordRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ad_group_id': 'str',
        'campaign_id': 'str',
        'negative_keyword_match_type': 'str',
        'negative_keyword_text': 'str'
    }

    attribute_map = {
        'ad_group_id': 'adGroupId',
        'campaign_id': 'campaignId',
        'negative_keyword_match_type': 'negativeKeywordMatchType',
        'negative_keyword_text': 'negativeKeywordText'
    }

    def __init__(self, ad_group_id=None, campaign_id=None, negative_keyword_match_type=None, negative_keyword_text=None):  # noqa: E501
        """CreateNegativeKeywordRequest - a model defined in Swagger"""  # noqa: E501
        self._ad_group_id = None
        self._campaign_id = None
        self._negative_keyword_match_type = None
        self._negative_keyword_text = None
        self.discriminator = None
        if ad_group_id is not None:
            self.ad_group_id = ad_group_id
        if campaign_id is not None:
            self.campaign_id = campaign_id
        if negative_keyword_match_type is not None:
            self.negative_keyword_match_type = negative_keyword_match_type
        if negative_keyword_text is not None:
            self.negative_keyword_text = negative_keyword_text

    @property
    def ad_group_id(self):
        """Gets the ad_group_id of this CreateNegativeKeywordRequest.  # noqa: E501

        This adGroupId is created when an ad group is first created and associated with a campaign. This is the ad group to which the corresponding negative keyword will be added.<br /><br /><span class=\"tablenote\"><b>Note:</b> You can call the  <a href=\"/api-docs/sell/marketing/resources/adgroup/methods/getAdGroups\">getAdGroups</a> method to retrieve the ad group IDs for a seller.</span><br /><br /><i>Required if</i> the negative keyword is being created at the ad group level.  # noqa: E501

        :return: The ad_group_id of this CreateNegativeKeywordRequest.  # noqa: E501
        :rtype: str
        """
        return self._ad_group_id

    @ad_group_id.setter
    def ad_group_id(self, ad_group_id):
        """Sets the ad_group_id of this CreateNegativeKeywordRequest.

        This adGroupId is created when an ad group is first created and associated with a campaign. This is the ad group to which the corresponding negative keyword will be added.<br /><br /><span class=\"tablenote\"><b>Note:</b> You can call the  <a href=\"/api-docs/sell/marketing/resources/adgroup/methods/getAdGroups\">getAdGroups</a> method to retrieve the ad group IDs for a seller.</span><br /><br /><i>Required if</i> the negative keyword is being created at the ad group level.  # noqa: E501

        :param ad_group_id: The ad_group_id of this CreateNegativeKeywordRequest.  # noqa: E501
        :type: str
        """

        self._ad_group_id = ad_group_id

    @property
    def campaign_id(self):
        """Gets the campaign_id of this CreateNegativeKeywordRequest.  # noqa: E501

        A unique eBay-assigned ID for a campaign. This ID is generated when a campaign is created.<br /><br /><i>Required if</i> the negative keyword is being created at the ad group level.  # noqa: E501

        :return: The campaign_id of this CreateNegativeKeywordRequest.  # noqa: E501
        :rtype: str
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this CreateNegativeKeywordRequest.

        A unique eBay-assigned ID for a campaign. This ID is generated when a campaign is created.<br /><br /><i>Required if</i> the negative keyword is being created at the ad group level.  # noqa: E501

        :param campaign_id: The campaign_id of this CreateNegativeKeywordRequest.  # noqa: E501
        :type: str
        """

        self._campaign_id = campaign_id

    @property
    def negative_keyword_match_type(self):
        """Gets the negative_keyword_match_type of this CreateNegativeKeywordRequest.  # noqa: E501

        A field that defines the match type for the negative keyword.<br /><br /><span class=\"tablenote\"><span style=\"color:#004680\"><strong>Note:</strong></span> Broad matching of negative keywords is not currently supported.</span><br /><b>Valid Values:</b><ul><li><code>EXACT</code></li><li><code>PHRASE</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/marketing/types/pls:NegativeKeywordMatchTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The negative_keyword_match_type of this CreateNegativeKeywordRequest.  # noqa: E501
        :rtype: str
        """
        return self._negative_keyword_match_type

    @negative_keyword_match_type.setter
    def negative_keyword_match_type(self, negative_keyword_match_type):
        """Sets the negative_keyword_match_type of this CreateNegativeKeywordRequest.

        A field that defines the match type for the negative keyword.<br /><br /><span class=\"tablenote\"><span style=\"color:#004680\"><strong>Note:</strong></span> Broad matching of negative keywords is not currently supported.</span><br /><b>Valid Values:</b><ul><li><code>EXACT</code></li><li><code>PHRASE</code></li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/marketing/types/pls:NegativeKeywordMatchTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param negative_keyword_match_type: The negative_keyword_match_type of this CreateNegativeKeywordRequest.  # noqa: E501
        :type: str
        """

        self._negative_keyword_match_type = negative_keyword_match_type

    @property
    def negative_keyword_text(self):
        """Gets the negative_keyword_text of this CreateNegativeKeywordRequest.  # noqa: E501

        The negative keyword text.  # noqa: E501

        :return: The negative_keyword_text of this CreateNegativeKeywordRequest.  # noqa: E501
        :rtype: str
        """
        return self._negative_keyword_text

    @negative_keyword_text.setter
    def negative_keyword_text(self, negative_keyword_text):
        """Sets the negative_keyword_text of this CreateNegativeKeywordRequest.

        The negative keyword text.  # noqa: E501

        :param negative_keyword_text: The negative_keyword_text of this CreateNegativeKeywordRequest.  # noqa: E501
        :type: str
        """

        self._negative_keyword_text = negative_keyword_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateNegativeKeywordRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateNegativeKeywordRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Feed API

    <p>The <strong>Feed API</strong> lets sellers upload input files, download reports and files including their status, filter reports using URI parameters, and retrieve customer service metrics task details.</p>  # noqa: E501

    OpenAPI spec version: v1.3.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from ...sell_feed.models.create_inventory_task_request import CreateInventoryTaskRequest
from ...sell_feed.models.create_order_task_request import CreateOrderTaskRequest
from ...sell_feed.models.create_service_metrics_task_request import CreateServiceMetricsTaskRequest
from ...sell_feed.models.create_task_request import CreateTaskRequest
from ...sell_feed.models.create_user_schedule_request import CreateUserScheduleRequest
from ...sell_feed.models.customer_service_metric_task_collection import CustomerServiceMetricTaskCollection
from ...sell_feed.models.customer_service_metrics_filter_criteria import CustomerServiceMetricsFilterCriteria
from ...sell_feed.models.date_range import DateRange
from ...sell_feed.models.error import Error
from ...sell_feed.models.error_parameter import ErrorParameter
from ...sell_feed.models.form_data_content_disposition import FormDataContentDisposition
from ...sell_feed.models.inventory_filter_criteria import InventoryFilterCriteria
from ...sell_feed.models.inventory_task import InventoryTask
from ...sell_feed.models.inventory_task_collection import InventoryTaskCollection
from ...sell_feed.models.order_filter_criteria import OrderFilterCriteria
from ...sell_feed.models.order_task import OrderTask
from ...sell_feed.models.order_task_collection import OrderTaskCollection
from ...sell_feed.models.schedule_template_collection import ScheduleTemplateCollection
from ...sell_feed.models.schedule_template_response import ScheduleTemplateResponse
from ...sell_feed.models.service_metrics_task import ServiceMetricsTask
from ...sell_feed.models.streaming_output import StreamingOutput
from ...sell_feed.models.supported_configuration import SupportedConfiguration
from ...sell_feed.models.task import Task
from ...sell_feed.models.task_collection import TaskCollection
from ...sell_feed.models.update_user_schedule_request import UpdateUserScheduleRequest
from ...sell_feed.models.upload_summary import UploadSummary
from ...sell_feed.models.user_schedule_collection import UserScheduleCollection
from ...sell_feed.models.user_schedule_response import UserScheduleResponse



# coding: utf-8

"""
    Logistics API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units.</span><br /><br />The <b>Logistics API</b> resources offer the following capabilities: <ul><li><b>shipping_quote</b> &ndash; Consolidates into a list a set of live shipping rates, or quotes, from which you can select a rate to ship a package.</li> <li><b>shipment</b> &ndash; Creates a \"shipment\" for the selected shipping rate.</li></ul> Call <b>createShippingQuote</b> to get a list of live shipping rates. The rates returned are all valid for a specific time window and all quoted prices are at eBay-negotiated rates. <br><br>Select one of the live rates and using its associated <b>rateId</b>, create a \"shipment\" for the package by calling <b>createFromShippingQuote</b>. Creating a shipment completes an agreement, and the cost of the base service and any added shipping options are summed into the returned <b>totalShippingCost</b> value. This action also generates a shipping label that you can use to ship the package.  The total cost of the shipment is incurred when the package is shipped using the supplied shipping label.  <p class=\"tablenote\"><b>Important!</b> Sellers must set up a payment method via their eBay account before they can use the methods in this API to create a shipment and the associated shipping label.</p>  # noqa: E501

    OpenAPI spec version: v1_beta.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ShippingQuote(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'creation_date': 'str',
        'expiration_date': 'str',
        'orders': 'list[Order]',
        'package_specification': 'PackageSpecification',
        'rates': 'list[Rate]',
        'ship_from': 'Contact',
        'shipping_quote_id': 'str',
        'ship_to': 'Contact',
        'warnings': 'list[Error]'
    }

    attribute_map = {
        'creation_date': 'creationDate',
        'expiration_date': 'expirationDate',
        'orders': 'orders',
        'package_specification': 'packageSpecification',
        'rates': 'rates',
        'ship_from': 'shipFrom',
        'shipping_quote_id': 'shippingQuoteId',
        'ship_to': 'shipTo',
        'warnings': 'warnings'
    }

    def __init__(self, creation_date=None, expiration_date=None, orders=None, package_specification=None, rates=None, ship_from=None, shipping_quote_id=None, ship_to=None, warnings=None):  # noqa: E501
        """ShippingQuote - a model defined in Swagger"""  # noqa: E501
        self._creation_date = None
        self._expiration_date = None
        self._orders = None
        self._package_specification = None
        self._rates = None
        self._ship_from = None
        self._shipping_quote_id = None
        self._ship_to = None
        self._warnings = None
        self.discriminator = None
        if creation_date is not None:
            self.creation_date = creation_date
        if expiration_date is not None:
            self.expiration_date = expiration_date
        if orders is not None:
            self.orders = orders
        if package_specification is not None:
            self.package_specification = package_specification
        if rates is not None:
            self.rates = rates
        if ship_from is not None:
            self.ship_from = ship_from
        if shipping_quote_id is not None:
            self.shipping_quote_id = shipping_quote_id
        if ship_to is not None:
            self.ship_to = ship_to
        if warnings is not None:
            self.warnings = warnings

    @property
    def creation_date(self):
        """Gets the creation_date of this ShippingQuote.  # noqa: E501

        The date and time this quote was created, expressed as an ISO 8601 UTC string.  # noqa: E501

        :return: The creation_date of this ShippingQuote.  # noqa: E501
        :rtype: str
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this ShippingQuote.

        The date and time this quote was created, expressed as an ISO 8601 UTC string.  # noqa: E501

        :param creation_date: The creation_date of this ShippingQuote.  # noqa: E501
        :type: str
        """

        self._creation_date = creation_date

    @property
    def expiration_date(self):
        """Gets the expiration_date of this ShippingQuote.  # noqa: E501

        The last date and time that this quote will be honored, expressed as an ISO 8601 UTC string. After this time the quote expires and the expressed rates can no longer be purchased.  # noqa: E501

        :return: The expiration_date of this ShippingQuote.  # noqa: E501
        :rtype: str
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this ShippingQuote.

        The last date and time that this quote will be honored, expressed as an ISO 8601 UTC string. After this time the quote expires and the expressed rates can no longer be purchased.  # noqa: E501

        :param expiration_date: The expiration_date of this ShippingQuote.  # noqa: E501
        :type: str
        """

        self._expiration_date = expiration_date

    @property
    def orders(self):
        """Gets the orders of this ShippingQuote.  # noqa: E501

        This list value is optionally assigned by the seller. When present, each element in the returned list contains seller-assigned information about an order (such as an order number). Because a package can contain all or part of one or more orders, this field provides a way for sellers to identify the packages that contain specific orders.  # noqa: E501

        :return: The orders of this ShippingQuote.  # noqa: E501
        :rtype: list[Order]
        """
        return self._orders

    @orders.setter
    def orders(self, orders):
        """Sets the orders of this ShippingQuote.

        This list value is optionally assigned by the seller. When present, each element in the returned list contains seller-assigned information about an order (such as an order number). Because a package can contain all or part of one or more orders, this field provides a way for sellers to identify the packages that contain specific orders.  # noqa: E501

        :param orders: The orders of this ShippingQuote.  # noqa: E501
        :type: list[Order]
        """

        self._orders = orders

    @property
    def package_specification(self):
        """Gets the package_specification of this ShippingQuote.  # noqa: E501


        :return: The package_specification of this ShippingQuote.  # noqa: E501
        :rtype: PackageSpecification
        """
        return self._package_specification

    @package_specification.setter
    def package_specification(self, package_specification):
        """Sets the package_specification of this ShippingQuote.


        :param package_specification: The package_specification of this ShippingQuote.  # noqa: E501
        :type: PackageSpecification
        """

        self._package_specification = package_specification

    @property
    def rates(self):
        """Gets the rates of this ShippingQuote.  # noqa: E501

        A list of <i>rates</i> where each rate, as identified by a <b>rateId</b>, contains information about a specific shipping service offered by a carrier.  Rates include shipping carrier and service, the to and from locations, the pickup and delivery windows, the seller's shipping parameters, the service constraints, and the cost for the base service and a list of additional shipping options.  <br><br>Each rate offered is supported by a label service where you can purchase the rate, and associated shipping label, via a call to <b>createFromShippingQuote</b>.  # noqa: E501

        :return: The rates of this ShippingQuote.  # noqa: E501
        :rtype: list[Rate]
        """
        return self._rates

    @rates.setter
    def rates(self, rates):
        """Sets the rates of this ShippingQuote.

        A list of <i>rates</i> where each rate, as identified by a <b>rateId</b>, contains information about a specific shipping service offered by a carrier.  Rates include shipping carrier and service, the to and from locations, the pickup and delivery windows, the seller's shipping parameters, the service constraints, and the cost for the base service and a list of additional shipping options.  <br><br>Each rate offered is supported by a label service where you can purchase the rate, and associated shipping label, via a call to <b>createFromShippingQuote</b>.  # noqa: E501

        :param rates: The rates of this ShippingQuote.  # noqa: E501
        :type: list[Rate]
        """

        self._rates = rates

    @property
    def ship_from(self):
        """Gets the ship_from of this ShippingQuote.  # noqa: E501


        :return: The ship_from of this ShippingQuote.  # noqa: E501
        :rtype: Contact
        """
        return self._ship_from

    @ship_from.setter
    def ship_from(self, ship_from):
        """Sets the ship_from of this ShippingQuote.


        :param ship_from: The ship_from of this ShippingQuote.  # noqa: E501
        :type: Contact
        """

        self._ship_from = ship_from

    @property
    def shipping_quote_id(self):
        """Gets the shipping_quote_id of this ShippingQuote.  # noqa: E501

        The unique eBay-assigned ID for this shipping quote. The value of this field is associated with a specific package, based on its origin, destination, and size.  # noqa: E501

        :return: The shipping_quote_id of this ShippingQuote.  # noqa: E501
        :rtype: str
        """
        return self._shipping_quote_id

    @shipping_quote_id.setter
    def shipping_quote_id(self, shipping_quote_id):
        """Sets the shipping_quote_id of this ShippingQuote.

        The unique eBay-assigned ID for this shipping quote. The value of this field is associated with a specific package, based on its origin, destination, and size.  # noqa: E501

        :param shipping_quote_id: The shipping_quote_id of this ShippingQuote.  # noqa: E501
        :type: str
        """

        self._shipping_quote_id = shipping_quote_id

    @property
    def ship_to(self):
        """Gets the ship_to of this ShippingQuote.  # noqa: E501


        :return: The ship_to of this ShippingQuote.  # noqa: E501
        :rtype: Contact
        """
        return self._ship_to

    @ship_to.setter
    def ship_to(self, ship_to):
        """Sets the ship_to of this ShippingQuote.


        :param ship_to: The ship_to of this ShippingQuote.  # noqa: E501
        :type: Contact
        """

        self._ship_to = ship_to

    @property
    def warnings(self):
        """Gets the warnings of this ShippingQuote.  # noqa: E501

        A list of any warnings triggered by the request.  # noqa: E501

        :return: The warnings of this ShippingQuote.  # noqa: E501
        :rtype: list[Error]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this ShippingQuote.

        A list of any warnings triggered by the request.  # noqa: E501

        :param warnings: The warnings of this ShippingQuote.  # noqa: E501
        :type: list[Error]
        """

        self._warnings = warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShippingQuote, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShippingQuote):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Fulfillment API

    Use the Fulfillment API to complete the process of packaging, addressing, handling, and shipping each order on behalf of the seller, in accordance with the payment method and timing specified at checkout.  # noqa: E501

    OpenAPI spec version: v1.19.18
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FileInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_id': 'str',
        'file_type': 'str',
        'name': 'str',
        'uploaded_date': 'str'
    }

    attribute_map = {
        'file_id': 'fileId',
        'file_type': 'fileType',
        'name': 'name',
        'uploaded_date': 'uploadedDate'
    }

    def __init__(self, file_id=None, file_type=None, name=None, uploaded_date=None):  # noqa: E501
        """FileInfo - a model defined in Swagger"""  # noqa: E501
        self._file_id = None
        self._file_type = None
        self._name = None
        self._uploaded_date = None
        self.discriminator = None
        if file_id is not None:
            self.file_id = file_id
        if file_type is not None:
            self.file_type = file_type
        if name is not None:
            self.name = name
        if uploaded_date is not None:
            self.uploaded_date = uploaded_date

    @property
    def file_id(self):
        """Gets the file_id of this FileInfo.  # noqa: E501

        The unique identifier of the evidence file.  # noqa: E501

        :return: The file_id of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this FileInfo.

        The unique identifier of the evidence file.  # noqa: E501

        :param file_id: The file_id of this FileInfo.  # noqa: E501
        :type: str
        """

        self._file_id = file_id

    @property
    def file_type(self):
        """Gets the file_type of this FileInfo.  # noqa: E501

        The type of file uploaded. Supported file extensions are .JPEG, .JPG, and .PNG., and maximum file size allowed is 1.5 MB.  # noqa: E501

        :return: The file_type of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        """Sets the file_type of this FileInfo.

        The type of file uploaded. Supported file extensions are .JPEG, .JPG, and .PNG., and maximum file size allowed is 1.5 MB.  # noqa: E501

        :param file_type: The file_type of this FileInfo.  # noqa: E501
        :type: str
        """

        self._file_type = file_type

    @property
    def name(self):
        """Gets the name of this FileInfo.  # noqa: E501

        The seller-provided name of the evidence file.  # noqa: E501

        :return: The name of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileInfo.

        The seller-provided name of the evidence file.  # noqa: E501

        :param name: The name of this FileInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def uploaded_date(self):
        """Gets the uploaded_date of this FileInfo.  # noqa: E501

        The timestamp in this field shows the date/time when the seller uploaded the evidential document to eBay. <br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :return: The uploaded_date of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._uploaded_date

    @uploaded_date.setter
    def uploaded_date(self, uploaded_date):
        """Sets the uploaded_date of this FileInfo.

        The timestamp in this field shows the date/time when the seller uploaded the evidential document to eBay. <br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :param uploaded_date: The uploaded_date of this FileInfo.  # noqa: E501
        :type: str
        """

        self._uploaded_date = uploaded_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deal API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units.</span><br /><br />This API allows third-party developers to search for and retrieve details about eBay deals and events, as well as the items associated with those deals and events.  # noqa: E501

    OpenAPI spec version: v1.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Error(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'domain': 'str',
        'error_id': 'int',
        'input_ref_ids': 'list[str]',
        'long_message': 'str',
        'message': 'str',
        'output_ref_ids': 'list[str]',
        'parameters': 'list[ErrorParameter]',
        'subdomain': 'str'
    }

    attribute_map = {
        'category': 'category',
        'domain': 'domain',
        'error_id': 'errorId',
        'input_ref_ids': 'inputRefIds',
        'long_message': 'longMessage',
        'message': 'message',
        'output_ref_ids': 'outputRefIds',
        'parameters': 'parameters',
        'subdomain': 'subdomain'
    }

    def __init__(self, category=None, domain=None, error_id=None, input_ref_ids=None, long_message=None, message=None, output_ref_ids=None, parameters=None, subdomain=None):  # noqa: E501
        """Error - a model defined in Swagger"""  # noqa: E501
        self._category = None
        self._domain = None
        self._error_id = None
        self._input_ref_ids = None
        self._long_message = None
        self._message = None
        self._output_ref_ids = None
        self._parameters = None
        self._subdomain = None
        self.discriminator = None
        if category is not None:
            self.category = category
        if domain is not None:
            self.domain = domain
        if error_id is not None:
            self.error_id = error_id
        if input_ref_ids is not None:
            self.input_ref_ids = input_ref_ids
        if long_message is not None:
            self.long_message = long_message
        if message is not None:
            self.message = message
        if output_ref_ids is not None:
            self.output_ref_ids = output_ref_ids
        if parameters is not None:
            self.parameters = parameters
        if subdomain is not None:
            self.subdomain = subdomain

    @property
    def category(self):
        """Gets the category of this Error.  # noqa: E501

        Identifies the type of erro.  # noqa: E501

        :return: The category of this Error.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Error.

        Identifies the type of erro.  # noqa: E501

        :param category: The category of this Error.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def domain(self):
        """Gets the domain of this Error.  # noqa: E501

        Name for the primary system where the error occurred. This is relevant for application errors.  # noqa: E501

        :return: The domain of this Error.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this Error.

        Name for the primary system where the error occurred. This is relevant for application errors.  # noqa: E501

        :param domain: The domain of this Error.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def error_id(self):
        """Gets the error_id of this Error.  # noqa: E501

        A unique number to identify the error.  # noqa: E501

        :return: The error_id of this Error.  # noqa: E501
        :rtype: int
        """
        return self._error_id

    @error_id.setter
    def error_id(self, error_id):
        """Sets the error_id of this Error.

        A unique number to identify the error.  # noqa: E501

        :param error_id: The error_id of this Error.  # noqa: E501
        :type: int
        """

        self._error_id = error_id

    @property
    def input_ref_ids(self):
        """Gets the input_ref_ids of this Error.  # noqa: E501

        An array of request elements most closely associated to the error.  # noqa: E501

        :return: The input_ref_ids of this Error.  # noqa: E501
        :rtype: list[str]
        """
        return self._input_ref_ids

    @input_ref_ids.setter
    def input_ref_ids(self, input_ref_ids):
        """Sets the input_ref_ids of this Error.

        An array of request elements most closely associated to the error.  # noqa: E501

        :param input_ref_ids: The input_ref_ids of this Error.  # noqa: E501
        :type: list[str]
        """

        self._input_ref_ids = input_ref_ids

    @property
    def long_message(self):
        """Gets the long_message of this Error.  # noqa: E501

        A more detailed explanation of the error.  # noqa: E501

        :return: The long_message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._long_message

    @long_message.setter
    def long_message(self, long_message):
        """Sets the long_message of this Error.

        A more detailed explanation of the error.  # noqa: E501

        :param long_message: The long_message of this Error.  # noqa: E501
        :type: str
        """

        self._long_message = long_message

    @property
    def message(self):
        """Gets the message of this Error.  # noqa: E501

        Information on how to correct the problem, in the end user's terms and language where applicable.  # noqa: E501

        :return: The message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Error.

        Information on how to correct the problem, in the end user's terms and language where applicable.  # noqa: E501

        :param message: The message of this Error.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def output_ref_ids(self):
        """Gets the output_ref_ids of this Error.  # noqa: E501

        An array of request elements most closely associated to the error.  # noqa: E501

        :return: The output_ref_ids of this Error.  # noqa: E501
        :rtype: list[str]
        """
        return self._output_ref_ids

    @output_ref_ids.setter
    def output_ref_ids(self, output_ref_ids):
        """Sets the output_ref_ids of this Error.

        An array of request elements most closely associated to the error.  # noqa: E501

        :param output_ref_ids: The output_ref_ids of this Error.  # noqa: E501
        :type: list[str]
        """

        self._output_ref_ids = output_ref_ids

    @property
    def parameters(self):
        """Gets the parameters of this Error.  # noqa: E501

        An array of name/value pairs that describe details the error condition. These are useful when multiple errors are returned.  # noqa: E501

        :return: The parameters of this Error.  # noqa: E501
        :rtype: list[ErrorParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Error.

        An array of name/value pairs that describe details the error condition. These are useful when multiple errors are returned.  # noqa: E501

        :param parameters: The parameters of this Error.  # noqa: E501
        :type: list[ErrorParameter]
        """

        self._parameters = parameters

    @property
    def subdomain(self):
        """Gets the subdomain of this Error.  # noqa: E501

        Further helps indicate which subsystem the error is coming from. System subcategories include: Initialization, Serialization, Security, Monitoring, Rate Limiting, etc.  # noqa: E501

        :return: The subdomain of this Error.  # noqa: E501
        :rtype: str
        """
        return self._subdomain

    @subdomain.setter
    def subdomain(self, subdomain):
        """Sets the subdomain of this Error.

        Further helps indicate which subsystem the error is coming from. System subcategories include: Initialization, Serialization, Security, Monitoring, Rate Limiting, etc.  # noqa: E501

        :param subdomain: The subdomain of this Error.  # noqa: E501
        :type: str
        """

        self._subdomain = subdomain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Error, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Compliance API

    Service for providing information to sellers about their listings being non-compliant, or at risk for becoming non-compliant, against eBay listing policies.  # noqa: E501

    OpenAPI spec version: 1.4.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from ..sell_compliance.api.listing_violation_api import ListingViolationApi
from ..sell_compliance.api.listing_violation_summary_api import ListingViolationSummaryApi
# import ApiClient
from ..sell_compliance.api_client import ApiClient
from ..sell_compliance.configuration import Configuration
# import models into sdk package
from ..sell_compliance.models.aspect_recommendations import AspectRecommendations
from ..sell_compliance.models.compliance_detail import ComplianceDetail
from ..sell_compliance.models.compliance_summary import ComplianceSummary
from ..sell_compliance.models.compliance_summary_info import ComplianceSummaryInfo
from ..sell_compliance.models.compliance_violation import ComplianceViolation
from ..sell_compliance.models.corrective_recommendations import CorrectiveRecommendations
from ..sell_compliance.models.error import Error
from ..sell_compliance.models.error_parameter import ErrorParameter
from ..sell_compliance.models.name_value_list import NameValueList
from ..sell_compliance.models.paged_compliance_violation_collection import PagedComplianceViolationCollection
from ..sell_compliance.models.product_recommendation import ProductRecommendation
from ..sell_compliance.models.suppress_violation_request import SuppressViolationRequest
from ..sell_compliance.models.variation_details import VariationDetails



# coding: utf-8

"""
    Marketing API

    <p>The <i>Marketing API </i> offers two platforms that sellers can use to promote and advertise their products:</p> <ul><li><b>Promoted Listings</b> is an eBay ad service that lets sellers set up <i>ad campaigns </i> for the products they want to promote. eBay displays the ads in search results and in other marketing modules as <b>SPONSORED</b> listings. If an item in a Promoted Listings campaign sells, the seller is assessed a Promoted Listings fee, which is a seller-specified percentage applied to the sales price. For complete details, refer to the <a href=\"/api-docs/sell/static/marketing/pl-landing.html\">Promoted Listings playbook</a>.</li><li><b>Promotions Manager</b> gives sellers a way to offer discounts on specific items as a way to attract buyers to their inventory. Sellers can set up discounts (such as \"20% off\" and other types of offers) on specific items or on an entire customer order. To further attract buyers, eBay prominently displays promotion <i>teasers</i> throughout buyer flows. For complete details, see <a href=\"/api-docs/sell/static/marketing/promotions-manager.html\">Promotions Manager</a>.</li></ul>  <p><b>Marketing reports</b>, on both the Promoted Listings and Promotions Manager platforms, give sellers information that shows the effectiveness of their marketing strategies. The data gives sellers the ability to review and fine tune their marketing efforts.</p> <p class=\"tablenote\"><b>Important!</b> Sellers must have an active eBay Store subscription, and they must accept the <b>Terms and Conditions</b> before they can make requests to these APIs in the Production environment. There are also site-specific listings requirements and restrictions associated with these marketing tools, as listed in the \"requirements and restrictions\" sections for <a href=\"/api-docs/sell/marketing/static/overview.html#PL-requirements\">Promoted Listings</a> and <a href=\"/api-docs/sell/marketing/static/overview.html#PM-requirements\">Promotions Manager</a>.</p> <p>The table below lists all the Marketing API calls grouped by resource.</p>  # noqa: E501

    OpenAPI spec version: v1.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ListingDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_price': 'Amount',
        'free_shipping': 'bool',
        'inventory_reference_id': 'str',
        'inventory_reference_type': 'str',
        'listing_category_id': 'str',
        'listing_condition': 'str',
        'listing_condition_id': 'str',
        'listing_id': 'str',
        'listing_promotion_statuses': 'list[ItemMarkdownStatus]',
        'quantity': 'int',
        'store_category_id': 'str',
        'title': 'str'
    }

    attribute_map = {
        'current_price': 'currentPrice',
        'free_shipping': 'freeShipping',
        'inventory_reference_id': 'inventoryReferenceId',
        'inventory_reference_type': 'inventoryReferenceType',
        'listing_category_id': 'listingCategoryId',
        'listing_condition': 'listingCondition',
        'listing_condition_id': 'listingConditionId',
        'listing_id': 'listingId',
        'listing_promotion_statuses': 'listingPromotionStatuses',
        'quantity': 'quantity',
        'store_category_id': 'storeCategoryId',
        'title': 'title'
    }

    def __init__(self, current_price=None, free_shipping=None, inventory_reference_id=None, inventory_reference_type=None, listing_category_id=None, listing_condition=None, listing_condition_id=None, listing_id=None, listing_promotion_statuses=None, quantity=None, store_category_id=None, title=None):  # noqa: E501
        """ListingDetail - a model defined in Swagger"""  # noqa: E501
        self._current_price = None
        self._free_shipping = None
        self._inventory_reference_id = None
        self._inventory_reference_type = None
        self._listing_category_id = None
        self._listing_condition = None
        self._listing_condition_id = None
        self._listing_id = None
        self._listing_promotion_statuses = None
        self._quantity = None
        self._store_category_id = None
        self._title = None
        self.discriminator = None
        if current_price is not None:
            self.current_price = current_price
        if free_shipping is not None:
            self.free_shipping = free_shipping
        if inventory_reference_id is not None:
            self.inventory_reference_id = inventory_reference_id
        if inventory_reference_type is not None:
            self.inventory_reference_type = inventory_reference_type
        if listing_category_id is not None:
            self.listing_category_id = listing_category_id
        if listing_condition is not None:
            self.listing_condition = listing_condition
        if listing_condition_id is not None:
            self.listing_condition_id = listing_condition_id
        if listing_id is not None:
            self.listing_id = listing_id
        if listing_promotion_statuses is not None:
            self.listing_promotion_statuses = listing_promotion_statuses
        if quantity is not None:
            self.quantity = quantity
        if store_category_id is not None:
            self.store_category_id = store_category_id
        if title is not None:
            self.title = title

    @property
    def current_price(self):
        """Gets the current_price of this ListingDetail.  # noqa: E501


        :return: The current_price of this ListingDetail.  # noqa: E501
        :rtype: Amount
        """
        return self._current_price

    @current_price.setter
    def current_price(self, current_price):
        """Sets the current_price of this ListingDetail.


        :param current_price: The current_price of this ListingDetail.  # noqa: E501
        :type: Amount
        """

        self._current_price = current_price

    @property
    def free_shipping(self):
        """Gets the free_shipping of this ListingDetail.  # noqa: E501

        If set to <code>true</code>, the seller pays for the shipping (or that the item is marked for local pickup only) In this case, the listing does not have an associated shipping cost for the first listed domestic-shipping option (even if the first domestic-shipping option specifies a flat-rate or calculated shipping option). If <code>false</code>, the buyer is required to pay for a flat-rate or calculated cost shipping service.  # noqa: E501

        :return: The free_shipping of this ListingDetail.  # noqa: E501
        :rtype: bool
        """
        return self._free_shipping

    @free_shipping.setter
    def free_shipping(self, free_shipping):
        """Sets the free_shipping of this ListingDetail.

        If set to <code>true</code>, the seller pays for the shipping (or that the item is marked for local pickup only) In this case, the listing does not have an associated shipping cost for the first listed domestic-shipping option (even if the first domestic-shipping option specifies a flat-rate or calculated shipping option). If <code>false</code>, the buyer is required to pay for a flat-rate or calculated cost shipping service.  # noqa: E501

        :param free_shipping: The free_shipping of this ListingDetail.  # noqa: E501
        :type: bool
        """

        self._free_shipping = free_shipping

    @property
    def inventory_reference_id(self):
        """Gets the inventory_reference_id of this ListingDetail.  # noqa: E501

        The seller's inventory reference ID for a listing. Also known as the \"SKU\" or \"custom label,\" an inventory reference ID is either the ID of the listing or, if the listing has variations (such as a shirt that's available in multiple sizes and colors), the ID of the parent listing.  # noqa: E501

        :return: The inventory_reference_id of this ListingDetail.  # noqa: E501
        :rtype: str
        """
        return self._inventory_reference_id

    @inventory_reference_id.setter
    def inventory_reference_id(self, inventory_reference_id):
        """Sets the inventory_reference_id of this ListingDetail.

        The seller's inventory reference ID for a listing. Also known as the \"SKU\" or \"custom label,\" an inventory reference ID is either the ID of the listing or, if the listing has variations (such as a shirt that's available in multiple sizes and colors), the ID of the parent listing.  # noqa: E501

        :param inventory_reference_id: The inventory_reference_id of this ListingDetail.  # noqa: E501
        :type: str
        """

        self._inventory_reference_id = inventory_reference_id

    @property
    def inventory_reference_type(self):
        """Gets the inventory_reference_type of this ListingDetail.  # noqa: E501

        Indicates the type of the <b>inventoryReferenceId</b>, which can be either a single-SKU or a multi-SKU listing (<code>INVENTORY_ITEM</code> and <code>INVENTORY_ITEM_GROUP</code>, respectively).  <br><br><b>Note:</b> This value is not currently returned in the response.  # noqa: E501

        :return: The inventory_reference_type of this ListingDetail.  # noqa: E501
        :rtype: str
        """
        return self._inventory_reference_type

    @inventory_reference_type.setter
    def inventory_reference_type(self, inventory_reference_type):
        """Sets the inventory_reference_type of this ListingDetail.

        Indicates the type of the <b>inventoryReferenceId</b>, which can be either a single-SKU or a multi-SKU listing (<code>INVENTORY_ITEM</code> and <code>INVENTORY_ITEM_GROUP</code>, respectively).  <br><br><b>Note:</b> This value is not currently returned in the response.  # noqa: E501

        :param inventory_reference_type: The inventory_reference_type of this ListingDetail.  # noqa: E501
        :type: str
        """

        self._inventory_reference_type = inventory_reference_type

    @property
    def listing_category_id(self):
        """Gets the listing_category_id of this ListingDetail.  # noqa: E501

        The ID of the category that listing belongs to. The ID is a numeric and unique identifier for the category that is assigned by eBay.  # noqa: E501

        :return: The listing_category_id of this ListingDetail.  # noqa: E501
        :rtype: str
        """
        return self._listing_category_id

    @listing_category_id.setter
    def listing_category_id(self, listing_category_id):
        """Sets the listing_category_id of this ListingDetail.

        The ID of the category that listing belongs to. The ID is a numeric and unique identifier for the category that is assigned by eBay.  # noqa: E501

        :param listing_category_id: The listing_category_id of this ListingDetail.  # noqa: E501
        :type: str
        """

        self._listing_category_id = listing_category_id

    @property
    def listing_condition(self):
        """Gets the listing_condition of this ListingDetail.  # noqa: E501

        An eBay-assigned value that indicates condition of the associated item. For more information, see <a href=\"/api-docs/sell/static/metadata/condition-id-values.html\">Item condition ID and name values</a>.  # noqa: E501

        :return: The listing_condition of this ListingDetail.  # noqa: E501
        :rtype: str
        """
        return self._listing_condition

    @listing_condition.setter
    def listing_condition(self, listing_condition):
        """Sets the listing_condition of this ListingDetail.

        An eBay-assigned value that indicates condition of the associated item. For more information, see <a href=\"/api-docs/sell/static/metadata/condition-id-values.html\">Item condition ID and name values</a>.  # noqa: E501

        :param listing_condition: The listing_condition of this ListingDetail.  # noqa: E501
        :type: str
        """

        self._listing_condition = listing_condition

    @property
    def listing_condition_id(self):
        """Gets the listing_condition_id of this ListingDetail.  # noqa: E501

        The ID of the condition associated with the item. For more information, see <a href=\"/api-docs/sell/static/metadata/condition-id-values.html\">Item condition ID and name values</a>.<br /><br /><span class=\"tablenote\"><b>Note: </b> This value is not currently returned in the response.</span>  # noqa: E501

        :return: The listing_condition_id of this ListingDetail.  # noqa: E501
        :rtype: str
        """
        return self._listing_condition_id

    @listing_condition_id.setter
    def listing_condition_id(self, listing_condition_id):
        """Sets the listing_condition_id of this ListingDetail.

        The ID of the condition associated with the item. For more information, see <a href=\"/api-docs/sell/static/metadata/condition-id-values.html\">Item condition ID and name values</a>.<br /><br /><span class=\"tablenote\"><b>Note: </b> This value is not currently returned in the response.</span>  # noqa: E501

        :param listing_condition_id: The listing_condition_id of this ListingDetail.  # noqa: E501
        :type: str
        """

        self._listing_condition_id = listing_condition_id

    @property
    def listing_id(self):
        """Gets the listing_id of this ListingDetail.  # noqa: E501

        A unique eBay-assigned ID that is generated when the item is listed.  # noqa: E501

        :return: The listing_id of this ListingDetail.  # noqa: E501
        :rtype: str
        """
        return self._listing_id

    @listing_id.setter
    def listing_id(self, listing_id):
        """Sets the listing_id of this ListingDetail.

        A unique eBay-assigned ID that is generated when the item is listed.  # noqa: E501

        :param listing_id: The listing_id of this ListingDetail.  # noqa: E501
        :type: str
        """

        self._listing_id = listing_id

    @property
    def listing_promotion_statuses(self):
        """Gets the listing_promotion_statuses of this ListingDetail.  # noqa: E501

        A list of the status values assigned to the item and the date that each new status was assigned.  # noqa: E501

        :return: The listing_promotion_statuses of this ListingDetail.  # noqa: E501
        :rtype: list[ItemMarkdownStatus]
        """
        return self._listing_promotion_statuses

    @listing_promotion_statuses.setter
    def listing_promotion_statuses(self, listing_promotion_statuses):
        """Sets the listing_promotion_statuses of this ListingDetail.

        A list of the status values assigned to the item and the date that each new status was assigned.  # noqa: E501

        :param listing_promotion_statuses: The listing_promotion_statuses of this ListingDetail.  # noqa: E501
        :type: list[ItemMarkdownStatus]
        """

        self._listing_promotion_statuses = listing_promotion_statuses

    @property
    def quantity(self):
        """Gets the quantity of this ListingDetail.  # noqa: E501

        The number of items being sold in the listing.  # noqa: E501

        :return: The quantity of this ListingDetail.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this ListingDetail.

        The number of items being sold in the listing.  # noqa: E501

        :param quantity: The quantity of this ListingDetail.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def store_category_id(self):
        """Gets the store_category_id of this ListingDetail.  # noqa: E501

        Store CategoryId (if any) that to which the listing belongs. This field is blank if there is no seller Store category ID.  # noqa: E501

        :return: The store_category_id of this ListingDetail.  # noqa: E501
        :rtype: str
        """
        return self._store_category_id

    @store_category_id.setter
    def store_category_id(self, store_category_id):
        """Sets the store_category_id of this ListingDetail.

        Store CategoryId (if any) that to which the listing belongs. This field is blank if there is no seller Store category ID.  # noqa: E501

        :param store_category_id: The store_category_id of this ListingDetail.  # noqa: E501
        :type: str
        """

        self._store_category_id = store_category_id

    @property
    def title(self):
        """Gets the title of this ListingDetail.  # noqa: E501

        The seller-defined title of the listing that a seller can use to identify the item.  This label is not displayed in end-user flows.  # noqa: E501

        :return: The title of this ListingDetail.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ListingDetail.

        The seller-defined title of the listing that a seller can use to identify the item.  This label is not displayed in end-user flows.  # noqa: E501

        :param title: The title of this ListingDetail.  # noqa: E501
        :type: str
        """

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListingDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListingDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
     Seller Service Metrics API 

    The <i>Analytics API</i> provides data and information about a seller and their eBay business.  <br><br>The resources and methods in this API let sellers review information on their listing performance, metrics on their customer service performance, and details on their eBay seller performance rating.  <br><br>The three resources in the Analytics API provide the following data and information: <ul><li><b>Customer Service Metric</b> &ndash; Returns data on a seller's customer service performance as compared to other seller's in the same peer group.</li> <li><b>Traffic Report</b> &ndash; Returns data that shows how buyers are engaging with a seller's listings.</li> <li><b>Seller Standards Profile</b> &ndash; Returns data pertaining to a seller's performance rating.</li></ul> Sellers can use the data and information returned by the various Analytics API methods to determine where they can make improvements to increase sales and how they might improve their seller status as viewed by eBay buyers.  <br><br>For details on using this API, see <a href=\"/api-docs/sell/static/performance/analyzing-performance.html\" title=\"Selling Integration Guide\">Analyzing seller performance</a>.  # noqa: E501

    OpenAPI spec version: 1.2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from ...sell_analytics.models.benchmark_metadata import BenchmarkMetadata
from ...sell_analytics.models.cycle import Cycle
from ...sell_analytics.models.definition import Definition
from ...sell_analytics.models.dimension import Dimension
from ...sell_analytics.models.dimension_metric import DimensionMetric
from ...sell_analytics.models.distribution import Distribution
from ...sell_analytics.models.error import Error
from ...sell_analytics.models.error_parameter import ErrorParameter
from ...sell_analytics.models.evaluation_cycle import EvaluationCycle
from ...sell_analytics.models.find_seller_standards_profiles_response import FindSellerStandardsProfilesResponse
from ...sell_analytics.models.get_customer_service_metric_response import GetCustomerServiceMetricResponse
from ...sell_analytics.models.header import Header
from ...sell_analytics.models.metadata import Metadata
from ...sell_analytics.models.metadata_header import MetadataHeader
from ...sell_analytics.models.metadata_record import MetadataRecord
from ...sell_analytics.models.metric import Metric
from ...sell_analytics.models.metric_benchmark import MetricBenchmark
from ...sell_analytics.models.metric_distribution import MetricDistribution
from ...sell_analytics.models.record import Record
from ...sell_analytics.models.report import Report
from ...sell_analytics.models.standards_profile import StandardsProfile
from ...sell_analytics.models.value import Value



# coding: utf-8

"""
    Developer Registration API

    <span class=\"tablenote\"><b>Note:</b> The Client Registration API is not intended for use by developers who have previously registered for a Developer Account on the eBay platform.</span><br/>The Client Registration API provides Dynamic Client Registration for regulated Third Party Providers (TPPs) who are, or will be, engaged in financial transactions on behalf of individuals domiciled in the EU/UK. This is required by the EU's Second Payment Services Directive (PSD2) which requires all regulated Account Servicing Payment Service Providers (ASPSPs) to provide secure APIs to access account and payment services on behalf of account holders.<br/><br/>A successful registration response returns a <b>HTTP 201 Created</b> status code with a JSON payload [RFC7519] that includes registration information.  # noqa: E501

    OpenAPI spec version: v1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ClientDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'client_id': 'str',
        'client_id_issued_at': 'int',
        'client_name': 'str',
        'client_secret': 'str',
        'client_secret_expires_at': 'int',
        'contacts': 'list[str]',
        'grant_types': 'list[str]',
        'policy_uri': 'str',
        'redirect_uris': 'list[str]',
        'scope': 'str',
        'software_id': 'str',
        'software_statement': 'str'
    }

    attribute_map = {
        'client_id': 'client_id',
        'client_id_issued_at': 'client_id_issued_at',
        'client_name': 'client_name',
        'client_secret': 'client_secret',
        'client_secret_expires_at': 'client_secret_expires_at',
        'contacts': 'contacts',
        'grant_types': 'grant_types',
        'policy_uri': 'policy_uri',
        'redirect_uris': 'redirect_uris',
        'scope': 'scope',
        'software_id': 'software_id',
        'software_statement': 'software_statement'
    }

    def __init__(self, client_id=None, client_id_issued_at=None, client_name=None, client_secret=None, client_secret_expires_at=None, contacts=None, grant_types=None, policy_uri=None, redirect_uris=None, scope=None, software_id=None, software_statement=None):  # noqa: E501
        """ClientDetails - a model defined in Swagger"""  # noqa: E501
        self._client_id = None
        self._client_id_issued_at = None
        self._client_name = None
        self._client_secret = None
        self._client_secret_expires_at = None
        self._contacts = None
        self._grant_types = None
        self._policy_uri = None
        self._redirect_uris = None
        self._scope = None
        self._software_id = None
        self._software_statement = None
        self.discriminator = None
        if client_id is not None:
            self.client_id = client_id
        if client_id_issued_at is not None:
            self.client_id_issued_at = client_id_issued_at
        if client_name is not None:
            self.client_name = client_name
        if client_secret is not None:
            self.client_secret = client_secret
        if client_secret_expires_at is not None:
            self.client_secret_expires_at = client_secret_expires_at
        if contacts is not None:
            self.contacts = contacts
        if grant_types is not None:
            self.grant_types = grant_types
        if policy_uri is not None:
            self.policy_uri = policy_uri
        if redirect_uris is not None:
            self.redirect_uris = redirect_uris
        if scope is not None:
            self.scope = scope
        if software_id is not None:
            self.software_id = software_id
        if software_statement is not None:
            self.software_statement = software_statement

    @property
    def client_id(self):
        """Gets the client_id of this ClientDetails.  # noqa: E501

        A unique, eBay-generated id assigned to the third party application at the time it was registered.  # noqa: E501

        :return: The client_id of this ClientDetails.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this ClientDetails.

        A unique, eBay-generated id assigned to the third party application at the time it was registered.  # noqa: E501

        :param client_id: The client_id of this ClientDetails.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_id_issued_at(self):
        """Gets the client_id_issued_at of this ClientDetails.  # noqa: E501

        The UNIX timestamp when the <code>client_id</code> was issued. This time is represented as the number of seconds from \"1970-01-01T00:00:00Z\", as measured in UTC, until the date/time of issuance. Refer to <a href=\"https://datatracker.ietf.org/doc/html/rfc7591#section-2.3 \" target= \"_blank \">RFC 7591 - OAuth 2.0 Dynamic Client Registration Protocol</a> for complete information.  # noqa: E501

        :return: The client_id_issued_at of this ClientDetails.  # noqa: E501
        :rtype: int
        """
        return self._client_id_issued_at

    @client_id_issued_at.setter
    def client_id_issued_at(self, client_id_issued_at):
        """Sets the client_id_issued_at of this ClientDetails.

        The UNIX timestamp when the <code>client_id</code> was issued. This time is represented as the number of seconds from \"1970-01-01T00:00:00Z\", as measured in UTC, until the date/time of issuance. Refer to <a href=\"https://datatracker.ietf.org/doc/html/rfc7591#section-2.3 \" target= \"_blank \">RFC 7591 - OAuth 2.0 Dynamic Client Registration Protocol</a> for complete information.  # noqa: E501

        :param client_id_issued_at: The client_id_issued_at of this ClientDetails.  # noqa: E501
        :type: int
        """

        self._client_id_issued_at = client_id_issued_at

    @property
    def client_name(self):
        """Gets the client_name of this ClientDetails.  # noqa: E501

        User-friendly name for the third party financial application.<br/><br/><span class=\"tablenote\"><b>Note:</b> Language tags are not supported. Therefore, <code>client_name</code> will be specified in English.</span>  # noqa: E501

        :return: The client_name of this ClientDetails.  # noqa: E501
        :rtype: str
        """
        return self._client_name

    @client_name.setter
    def client_name(self, client_name):
        """Sets the client_name of this ClientDetails.

        User-friendly name for the third party financial application.<br/><br/><span class=\"tablenote\"><b>Note:</b> Language tags are not supported. Therefore, <code>client_name</code> will be specified in English.</span>  # noqa: E501

        :param client_name: The client_name of this ClientDetails.  # noqa: E501
        :type: str
        """

        self._client_name = client_name

    @property
    def client_secret(self):
        """Gets the client_secret of this ClientDetails.  # noqa: E501

        A unique OAuth 2.0 secret string assigned by eBay to the third party application at the time it is registered. This value should be unique for multiple instances of a client using the same <code>client_id</code>. This value is used by confidential clients to authenticate to the token endpoint, as described in OAuth 2.0 [RFC6749], Section 2.3.1.<br/><br/><span class=\"tablenote\"><b>Note:</b> <code>client_secret</code> is unique to the organization identifier of subject name which contains jurisdiction, NCA Id, and Authorization Number.</span>  # noqa: E501

        :return: The client_secret of this ClientDetails.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this ClientDetails.

        A unique OAuth 2.0 secret string assigned by eBay to the third party application at the time it is registered. This value should be unique for multiple instances of a client using the same <code>client_id</code>. This value is used by confidential clients to authenticate to the token endpoint, as described in OAuth 2.0 [RFC6749], Section 2.3.1.<br/><br/><span class=\"tablenote\"><b>Note:</b> <code>client_secret</code> is unique to the organization identifier of subject name which contains jurisdiction, NCA Id, and Authorization Number.</span>  # noqa: E501

        :param client_secret: The client_secret of this ClientDetails.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def client_secret_expires_at(self):
        """Gets the client_secret_expires_at of this ClientDetails.  # noqa: E501

        The UNIX timestamp when the <code>client_secret</code> expires.<br/><br/><span class=\"tablenote\"><b>Note:</b> When a <code>client_secret</code> has been provided, this field is <b>REQUIRED</b>.</span><br/>A returned value of <b>0</b> indicates that the <code>client_secret</code> never expires.<br/><br/>This time is represented as the number of seconds from \"1970-01-01T00:00:00Z\", as measured in UTC, until the expiration date and time. Refer to <a href=\"https://datatracker.ietf.org/doc/html/rfc7591#section-3.2.1 \" target= \"_blank \">RFC 7591 - OAuth 2.0 Dynamic Client Registration Protocol section 3.2.1</a> for complete information.  # noqa: E501

        :return: The client_secret_expires_at of this ClientDetails.  # noqa: E501
        :rtype: int
        """
        return self._client_secret_expires_at

    @client_secret_expires_at.setter
    def client_secret_expires_at(self, client_secret_expires_at):
        """Sets the client_secret_expires_at of this ClientDetails.

        The UNIX timestamp when the <code>client_secret</code> expires.<br/><br/><span class=\"tablenote\"><b>Note:</b> When a <code>client_secret</code> has been provided, this field is <b>REQUIRED</b>.</span><br/>A returned value of <b>0</b> indicates that the <code>client_secret</code> never expires.<br/><br/>This time is represented as the number of seconds from \"1970-01-01T00:00:00Z\", as measured in UTC, until the expiration date and time. Refer to <a href=\"https://datatracker.ietf.org/doc/html/rfc7591#section-3.2.1 \" target= \"_blank \">RFC 7591 - OAuth 2.0 Dynamic Client Registration Protocol section 3.2.1</a> for complete information.  # noqa: E501

        :param client_secret_expires_at: The client_secret_expires_at of this ClientDetails.  # noqa: E501
        :type: int
        """

        self._client_secret_expires_at = client_secret_expires_at

    @property
    def contacts(self):
        """Gets the contacts of this ClientDetails.  # noqa: E501

        This container stores an array of email addresses for representatives at the third party provider responsible for the application being registered.  # noqa: E501

        :return: The contacts of this ClientDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this ClientDetails.

        This container stores an array of email addresses for representatives at the third party provider responsible for the application being registered.  # noqa: E501

        :param contacts: The contacts of this ClientDetails.  # noqa: E501
        :type: list[str]
        """

        self._contacts = contacts

    @property
    def grant_types(self):
        """Gets the grant_types of this ClientDetails.  # noqa: E501

        An array of OAuth 2.0 grant type strings that the client software can use at the token endpoint. Supported grant type values are:<br/><ul><li><code>authorization_code</code>: The authorization code grant type defined in OAuth 2.0, Section 4.1.</li><li><code>client_credentials</code>: The client credentials grant type defined in OAuth 2.0, Section 4.4.</li></ul>If the token endpoint is used in the grant type, the value of this parameter <b>MUST</b> be the same as the value of the <code>grant_type</code> parameter passed to the token endpoint defined in the grant type definition. Authorization servers <b>may</b> allow for other values as defined in the grant type extension process described in OAuth 2.0, Section 4.5. If omitted, the default behavior is that the client will use only the <code>authorization_code</code> Grant Type.  # noqa: E501

        :return: The grant_types of this ClientDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._grant_types

    @grant_types.setter
    def grant_types(self, grant_types):
        """Sets the grant_types of this ClientDetails.

        An array of OAuth 2.0 grant type strings that the client software can use at the token endpoint. Supported grant type values are:<br/><ul><li><code>authorization_code</code>: The authorization code grant type defined in OAuth 2.0, Section 4.1.</li><li><code>client_credentials</code>: The client credentials grant type defined in OAuth 2.0, Section 4.4.</li></ul>If the token endpoint is used in the grant type, the value of this parameter <b>MUST</b> be the same as the value of the <code>grant_type</code> parameter passed to the token endpoint defined in the grant type definition. Authorization servers <b>may</b> allow for other values as defined in the grant type extension process described in OAuth 2.0, Section 4.5. If omitted, the default behavior is that the client will use only the <code>authorization_code</code> Grant Type.  # noqa: E501

        :param grant_types: The grant_types of this ClientDetails.  # noqa: E501
        :type: list[str]
        """

        self._grant_types = grant_types

    @property
    def policy_uri(self):
        """Gets the policy_uri of this ClientDetails.  # noqa: E501

        The URL string pointing to a human-readable privacy policy document that describes how the third party provider collects, uses, retains, and discloses personal data.<br/><br/><span class=\"tablenote\"><b>Note:</b> Only HTTPS URLs are supported for <code>policy_uri</code> strings.</span><br/><span class=\"tablenote\"><b>Note:</b> This URL <b>must not</b> point to the eBay Privacy Policy.</span><br/>The authorization server should display this secure URL to the end-user if it is provided. The value of this field <b>must</b> point to a valid and secure web page.<br/><br/><span class=\"tablenote\"><b>Note:</b> Language tags are not supported. Therefore, <code>policy_uri</code> will be displayed in English.</span>  # noqa: E501

        :return: The policy_uri of this ClientDetails.  # noqa: E501
        :rtype: str
        """
        return self._policy_uri

    @policy_uri.setter
    def policy_uri(self, policy_uri):
        """Sets the policy_uri of this ClientDetails.

        The URL string pointing to a human-readable privacy policy document that describes how the third party provider collects, uses, retains, and discloses personal data.<br/><br/><span class=\"tablenote\"><b>Note:</b> Only HTTPS URLs are supported for <code>policy_uri</code> strings.</span><br/><span class=\"tablenote\"><b>Note:</b> This URL <b>must not</b> point to the eBay Privacy Policy.</span><br/>The authorization server should display this secure URL to the end-user if it is provided. The value of this field <b>must</b> point to a valid and secure web page.<br/><br/><span class=\"tablenote\"><b>Note:</b> Language tags are not supported. Therefore, <code>policy_uri</code> will be displayed in English.</span>  # noqa: E501

        :param policy_uri: The policy_uri of this ClientDetails.  # noqa: E501
        :type: str
        """

        self._policy_uri = policy_uri

    @property
    def redirect_uris(self):
        """Gets the redirect_uris of this ClientDetails.  # noqa: E501

        An eBay system-generated value assigned to the application. This value represents the redirect uri(s) submitted by the user either in the request payload (i.e., the <code>redirect_uris</code> field,) or the <code>software_statement</code>.  # noqa: E501

        :return: The redirect_uris of this ClientDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._redirect_uris

    @redirect_uris.setter
    def redirect_uris(self, redirect_uris):
        """Sets the redirect_uris of this ClientDetails.

        An eBay system-generated value assigned to the application. This value represents the redirect uri(s) submitted by the user either in the request payload (i.e., the <code>redirect_uris</code> field,) or the <code>software_statement</code>.  # noqa: E501

        :param redirect_uris: The redirect_uris of this ClientDetails.  # noqa: E501
        :type: list[str]
        """

        self._redirect_uris = redirect_uris

    @property
    def scope(self):
        """Gets the scope of this ClientDetails.  # noqa: E501

        String containing a space-separated list of scope values (as described in Section 3.3 of OAuth 2.0 [RFC6749]) that the client can use when requesting access tokens. The semantics of values in this list are service specific.  # noqa: E501

        :return: The scope of this ClientDetails.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this ClientDetails.

        String containing a space-separated list of scope values (as described in Section 3.3 of OAuth 2.0 [RFC6749]) that the client can use when requesting access tokens. The semantics of values in this list are service specific.  # noqa: E501

        :param scope: The scope of this ClientDetails.  # noqa: E501
        :type: str
        """

        self._scope = scope

    @property
    def software_id(self):
        """Gets the software_id of this ClientDetails.  # noqa: E501

        A unique identifier string provided by the client developer or software publisher at the time of registration that identifies the client software being registered.<br/><br/>Unlike <code>client_id</code> which should change between instances, the <CODE>software_id</code> should be the same value for all instances of the client software. That is, the <code>software_id</code> should remain unchanged across multiple updates or versions of the same piece of software.  # noqa: E501

        :return: The software_id of this ClientDetails.  # noqa: E501
        :rtype: str
        """
        return self._software_id

    @software_id.setter
    def software_id(self, software_id):
        """Sets the software_id of this ClientDetails.

        A unique identifier string provided by the client developer or software publisher at the time of registration that identifies the client software being registered.<br/><br/>Unlike <code>client_id</code> which should change between instances, the <CODE>software_id</code> should be the same value for all instances of the client software. That is, the <code>software_id</code> should remain unchanged across multiple updates or versions of the same piece of software.  # noqa: E501

        :param software_id: The software_id of this ClientDetails.  # noqa: E501
        :type: str
        """

        self._software_id = software_id

    @property
    def software_statement(self):
        """Gets the software_statement of this ClientDetails.  # noqa: E501

        The Software Statement Assertion (SSA), a JSON Web Token (JWT), that has been issued by the OpenBanking identifier. Refer to <a href=\"https://datatracker.ietf.org/doc/html/rfc7591#section-2.3 \" target= \"_blank \">RFC 7591 - OAuth 2.0 Dynamic Client Registration Protocol</a> for complete information.  # noqa: E501

        :return: The software_statement of this ClientDetails.  # noqa: E501
        :rtype: str
        """
        return self._software_statement

    @software_statement.setter
    def software_statement(self, software_statement):
        """Sets the software_statement of this ClientDetails.

        The Software Statement Assertion (SSA), a JSON Web Token (JWT), that has been issued by the OpenBanking identifier. Refer to <a href=\"https://datatracker.ietf.org/doc/html/rfc7591#section-2.3 \" target= \"_blank \">RFC 7591 - OAuth 2.0 Dynamic Client Registration Protocol</a> for complete information.  # noqa: E501

        :param software_statement: The software_statement of this ClientDetails.  # noqa: E501
        :type: str
        """

        self._software_statement = software_statement

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClientDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClientDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translation API

    This API allows 3rd party developers to translate item titles.  # noqa: E501

    OpenAPI spec version: v1_beta.1.4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TranslateResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_from': 'str',
        'to': 'str',
        'translations': 'list[Translation]'
    }

    attribute_map = {
        '_from': 'from',
        'to': 'to',
        'translations': 'translations'
    }

    def __init__(self, _from=None, to=None, translations=None):  # noqa: E501
        """TranslateResponse - a model defined in Swagger"""  # noqa: E501
        self.__from = None
        self._to = None
        self._translations = None
        self.discriminator = None
        if _from is not None:
            self._from = _from
        if to is not None:
            self.to = to
        if translations is not None:
            self.translations = translations

    @property
    def _from(self):
        """Gets the _from of this TranslateResponse.  # noqa: E501

        The enumeration value indicates the language of the input text. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/translation/types/api:LanguageEnum'>eBay API documentation</a>  # noqa: E501

        :return: The _from of this TranslateResponse.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this TranslateResponse.

        The enumeration value indicates the language of the input text. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/translation/types/api:LanguageEnum'>eBay API documentation</a>  # noqa: E501

        :param _from: The _from of this TranslateResponse.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this TranslateResponse.  # noqa: E501

        The enumeration value indicates the language of the translated text. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/translation/types/api:LanguageEnum'>eBay API documentation</a>  # noqa: E501

        :return: The to of this TranslateResponse.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this TranslateResponse.

        The enumeration value indicates the language of the translated text. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/translation/types/api:LanguageEnum'>eBay API documentation</a>  # noqa: E501

        :param to: The to of this TranslateResponse.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def translations(self):
        """Gets the translations of this TranslateResponse.  # noqa: E501

        An array showing the input and translated text. Only one input string can be translated at this time. Support for multiple continuous text strings is expected in the future.  # noqa: E501

        :return: The translations of this TranslateResponse.  # noqa: E501
        :rtype: list[Translation]
        """
        return self._translations

    @translations.setter
    def translations(self, translations):
        """Sets the translations of this TranslateResponse.

        An array showing the input and translated text. Only one input string can be translated at this time. Support for multiple continuous text strings is expected in the future.  # noqa: E501

        :param translations: The translations of this TranslateResponse.  # noqa: E501
        :type: list[Translation]
        """

        self._translations = translations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TranslateResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranslateResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Fulfillment API

    Use the Fulfillment API to complete the process of packaging, addressing, handling, and shipping each order on behalf of the seller, in accordance with the payment method and timing specified at checkout.  # noqa: E501

    OpenAPI spec version: v1.19.18
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ShippingStep(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ship_to': 'ExtendedContact',
        'ship_to_reference_id': 'str',
        'shipping_carrier_code': 'str',
        'shipping_service_code': 'str'
    }

    attribute_map = {
        'ship_to': 'shipTo',
        'ship_to_reference_id': 'shipToReferenceId',
        'shipping_carrier_code': 'shippingCarrierCode',
        'shipping_service_code': 'shippingServiceCode'
    }

    def __init__(self, ship_to=None, ship_to_reference_id=None, shipping_carrier_code=None, shipping_service_code=None):  # noqa: E501
        """ShippingStep - a model defined in Swagger"""  # noqa: E501
        self._ship_to = None
        self._ship_to_reference_id = None
        self._shipping_carrier_code = None
        self._shipping_service_code = None
        self.discriminator = None
        if ship_to is not None:
            self.ship_to = ship_to
        if ship_to_reference_id is not None:
            self.ship_to_reference_id = ship_to_reference_id
        if shipping_carrier_code is not None:
            self.shipping_carrier_code = shipping_carrier_code
        if shipping_service_code is not None:
            self.shipping_service_code = shipping_service_code

    @property
    def ship_to(self):
        """Gets the ship_to of this ShippingStep.  # noqa: E501


        :return: The ship_to of this ShippingStep.  # noqa: E501
        :rtype: ExtendedContact
        """
        return self._ship_to

    @ship_to.setter
    def ship_to(self, ship_to):
        """Sets the ship_to of this ShippingStep.


        :param ship_to: The ship_to of this ShippingStep.  # noqa: E501
        :type: ExtendedContact
        """

        self._ship_to = ship_to

    @property
    def ship_to_reference_id(self):
        """Gets the ship_to_reference_id of this ShippingStep.  # noqa: E501

        This is the unique identifer of the Global Shipping Program (GSP) shipment. This field is only returned if the line item is being shipped via GSP (the value of the <b>fulfillmentStartInstructions.ebaySupportedFulfillment</b> field will be <code>true</code>. The international shipping provider uses the <b>shipToReferenceId</b> value as the primary reference number to retrieve the relevant details about the buyer, the order, and the fulfillment, so the shipment can be completed. <br /><br />Sellers must include this value on the shipping label immediately above the street address of the international shipping provider. <br /><br />Example: \"Reference #1234567890123456\" <br /><br /><span class=\"tablenote\"><strong>Note:</strong> This value is the same as the <b>ShipToAddress.ReferenceID</b> value returned by the Trading API's GetOrders call.</span>  # noqa: E501

        :return: The ship_to_reference_id of this ShippingStep.  # noqa: E501
        :rtype: str
        """
        return self._ship_to_reference_id

    @ship_to_reference_id.setter
    def ship_to_reference_id(self, ship_to_reference_id):
        """Sets the ship_to_reference_id of this ShippingStep.

        This is the unique identifer of the Global Shipping Program (GSP) shipment. This field is only returned if the line item is being shipped via GSP (the value of the <b>fulfillmentStartInstructions.ebaySupportedFulfillment</b> field will be <code>true</code>. The international shipping provider uses the <b>shipToReferenceId</b> value as the primary reference number to retrieve the relevant details about the buyer, the order, and the fulfillment, so the shipment can be completed. <br /><br />Sellers must include this value on the shipping label immediately above the street address of the international shipping provider. <br /><br />Example: \"Reference #1234567890123456\" <br /><br /><span class=\"tablenote\"><strong>Note:</strong> This value is the same as the <b>ShipToAddress.ReferenceID</b> value returned by the Trading API's GetOrders call.</span>  # noqa: E501

        :param ship_to_reference_id: The ship_to_reference_id of this ShippingStep.  # noqa: E501
        :type: str
        """

        self._ship_to_reference_id = ship_to_reference_id

    @property
    def shipping_carrier_code(self):
        """Gets the shipping_carrier_code of this ShippingStep.  # noqa: E501

        The unique identifier of the shipping carrier being used to ship the line item. <br /><br /><span class=\"tablenote\"><strong>Note:</strong> The Trading API's <a href=\"https://developer.ebay.com/devzone/XML/docs/Reference/eBay/GeteBayDetails.html \" target=\"_blank\">GeteBayDetails</a> call can be used to retrieve the latest shipping carrier and shipping service option enumeration values.</span>  # noqa: E501

        :return: The shipping_carrier_code of this ShippingStep.  # noqa: E501
        :rtype: str
        """
        return self._shipping_carrier_code

    @shipping_carrier_code.setter
    def shipping_carrier_code(self, shipping_carrier_code):
        """Sets the shipping_carrier_code of this ShippingStep.

        The unique identifier of the shipping carrier being used to ship the line item. <br /><br /><span class=\"tablenote\"><strong>Note:</strong> The Trading API's <a href=\"https://developer.ebay.com/devzone/XML/docs/Reference/eBay/GeteBayDetails.html \" target=\"_blank\">GeteBayDetails</a> call can be used to retrieve the latest shipping carrier and shipping service option enumeration values.</span>  # noqa: E501

        :param shipping_carrier_code: The shipping_carrier_code of this ShippingStep.  # noqa: E501
        :type: str
        """

        self._shipping_carrier_code = shipping_carrier_code

    @property
    def shipping_service_code(self):
        """Gets the shipping_service_code of this ShippingStep.  # noqa: E501

        The unique identifier of the shipping service option being used to ship the line item.<br /><br /><span class=\"tablenote\"><strong>Note:</strong> Use the Trading API's <a href=\"https://developer.ebay.com/devzone/XML/docs/Reference/eBay/GeteBayDetails.html \" target=\"_blank\">GeteBayDetails</a> call to retrieve the latest shipping carrier and shipping service option enumeration values. When making the <a href=\"https://developer.ebay.com/devzone/XML/docs/Reference/eBay/GeteBayDetails.html \" target=\"_blank\">GeteBayDetails</a> call, include the <strong>DetailName</strong> field in the request payload and set its value to <code>ShippingServiceDetails</code>. Each valid shipping service option (returned in <strong>ShippingServiceDetails.ShippingService</strong> field) and corresponding shipping carrier (returned in <strong>ShippingServiceDetails.ShippingCarrier</strong> field) is returned in response payload.</span>  # noqa: E501

        :return: The shipping_service_code of this ShippingStep.  # noqa: E501
        :rtype: str
        """
        return self._shipping_service_code

    @shipping_service_code.setter
    def shipping_service_code(self, shipping_service_code):
        """Sets the shipping_service_code of this ShippingStep.

        The unique identifier of the shipping service option being used to ship the line item.<br /><br /><span class=\"tablenote\"><strong>Note:</strong> Use the Trading API's <a href=\"https://developer.ebay.com/devzone/XML/docs/Reference/eBay/GeteBayDetails.html \" target=\"_blank\">GeteBayDetails</a> call to retrieve the latest shipping carrier and shipping service option enumeration values. When making the <a href=\"https://developer.ebay.com/devzone/XML/docs/Reference/eBay/GeteBayDetails.html \" target=\"_blank\">GeteBayDetails</a> call, include the <strong>DetailName</strong> field in the request payload and set its value to <code>ShippingServiceDetails</code>. Each valid shipping service option (returned in <strong>ShippingServiceDetails.ShippingService</strong> field) and corresponding shipping carrier (returned in <strong>ShippingServiceDetails.ShippingCarrier</strong> field) is returned in response payload.</span>  # noqa: E501

        :param shipping_service_code: The shipping_service_code of this ShippingStep.  # noqa: E501
        :type: str
        """

        self._shipping_service_code = shipping_service_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShippingStep, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShippingStep):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Standard library imports
import copy
from json import load
import os

# Local imports

# TODO Instead of loading stale .json files get real-time reference info using this
# https://developer.ebay.com/devzone/xml/docs/reference/ebay/GeteBayDetails.html (this link is stale)


class Reference:
    """ Caches of reference information sourced from eBay's developer website. """

    _cache = {}

    @staticmethod
    def get_application_scopes() -> dict:
        """ Get eBay **Client Credential/Code** Grant Type Scopes
         that might be permitted when minting **Application** tokens.

         Dictionary keys are the scopes, and data are descriptions.

        Source https://developer.ebay.com/my/keys, Sandbox column, click OAuth Scopes, second section

        :return application_scopes (dict)
        """
        return Reference._get('application_scopes')

    @staticmethod
    def get_country_codes() -> dict:
        """ Get eBay country code information.

        A partial list of ISO 3166 standard two-letter codes that represent countries around the world.

        Source https://developer.ebay.com/devzone/xml/docs/reference/ebay/types/countrycodetype.html.

        :return country_codes (dict)
        """
        return Reference._get('country_codes')

    @staticmethod
    def get_currency_codes() -> dict:
        """ Get eBay country code information.

        A partial list of standard 3-digit ISO 4217 currency codes for currency used in countries around the world.

        Source https://developer.ebay.com/devzone/xml/docs/Reference/eBay/types/CurrencyCodeType.html.

        :return currency_codes (dict)
        """
        return Reference._get('currency_codes')

    @staticmethod
    def get_global_id_values() -> dict:
        """ Get eBay global id information.

        The Global ID is a unique identifier for combinations of site, language, and territory.
        Global ID values are returned in globalId and are used as input for the X-EBAY-SOA-GLOBAL-ID header.
        The global ID you use must correspond to an eBay site with a valid site ID.
        See https://developer.ebay.com/Devzone/merchandising/docs/Concepts/SiteIDToGlobalID.html
        eBay Site ID to Global ID Mapping for a list of global IDs you can use with the API calls.

        Source https://developer.ebay.com/Devzone/merchandising/docs/CallRef/Enums/GlobalIdList.html.

        :return global_id_values (dict)
        """
        return Reference._get('global_id_values')

    @staticmethod
    def get_marketplace_id_values() -> dict:
        """ Get eBay marketplace id information.

        The following table lists the set of supported Marketplace IDs, their associated countries,
        the URLs to the marketplaces, and the locales supported by each marketplace

        Source https://developer.ebay.com/api-docs/static/rest-request-components.html#marketpl.

        :return marketplace_id_values (dict)
        """
        return Reference._get('marketplace_id_values')

    @staticmethod
    def get_user_scopes() -> dict:
        """ Get eBay **Authorization Code** Grant Type Scopes
        that might be permitted when minting **User Access** tokens.

        Dictionary keys are the scopes, and data are descriptions.

        Source https://developer.ebay.com/my/keys, Sandbox column, click OAuth Scopes, first section

        :return user_scopes (dict)
        """
        return Reference._get('user_scopes')

    @staticmethod
    def _get(name) -> dict:
        """
        Get information from the json files.

        :param name (str, required)
        :return information (dict)
        """
        if name not in Reference._cache:
            # get the path to this python file, which is also where the data file directory is
            path, _fn = os.path.split(os.path.realpath(__file__))
            # to the path join the data file name and extension
            path_name = os.path.join(path, 'references', name + '.json')
            with open(path_name) as file_handle:
                Reference._cache[name] = load(file_handle)
        return copy.deepcopy(Reference._cache[name])



# coding: utf-8

"""
    Feed API

    <p>The <strong>Feed API</strong> lets sellers upload input files, download reports and files including their status, filter reports using URI parameters, and retrieve customer service metrics task details.</p>  # noqa: E501

    OpenAPI spec version: v1.3.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UploadSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'failure_count': 'int',
        'success_count': 'int'
    }

    attribute_map = {
        'failure_count': 'failureCount',
        'success_count': 'successCount'
    }

    def __init__(self, failure_count=None, success_count=None):  # noqa: E501
        """UploadSummary - a model defined in Swagger"""  # noqa: E501
        self._failure_count = None
        self._success_count = None
        self.discriminator = None
        if failure_count is not None:
            self.failure_count = failure_count
        if success_count is not None:
            self.success_count = success_count

    @property
    def failure_count(self):
        """Gets the failure_count of this UploadSummary.  # noqa: E501

        The number of records, such as the number of listings created or the number of pictures uploaded to a listing, that failed to process during the upload feed. Check the response file and correct any issues mentioned. If the feed fails before processing, no response file is provided. In this case check the REST output response.  # noqa: E501

        :return: The failure_count of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._failure_count

    @failure_count.setter
    def failure_count(self, failure_count):
        """Sets the failure_count of this UploadSummary.

        The number of records, such as the number of listings created or the number of pictures uploaded to a listing, that failed to process during the upload feed. Check the response file and correct any issues mentioned. If the feed fails before processing, no response file is provided. In this case check the REST output response.  # noqa: E501

        :param failure_count: The failure_count of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._failure_count = failure_count

    @property
    def success_count(self):
        """Gets the success_count of this UploadSummary.  # noqa: E501

        The number of records that were successfully processed during the upload feed.  # noqa: E501

        :return: The success_count of this UploadSummary.  # noqa: E501
        :rtype: int
        """
        return self._success_count

    @success_count.setter
    def success_count(self, success_count):
        """Sets the success_count of this UploadSummary.

        The number of records that were successfully processed during the upload feed.  # noqa: E501

        :param success_count: The success_count of this UploadSummary.  # noqa: E501
        :type: int
        """

        self._success_count = success_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UploadSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deal API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units.</span><br /><br />This API allows third-party developers to search for and retrieve details about eBay deals and events, as well as the items associated with those deals and events.  # noqa: E501

    OpenAPI spec version: v1.3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EventItemSearchResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'event_items': 'list[EventItem]',
        'href': 'str',
        'limit': 'int',
        'next': 'str',
        'offset': 'int',
        'prev': 'str',
        'total': 'int'
    }

    attribute_map = {
        'event_items': 'eventItems',
        'href': 'href',
        'limit': 'limit',
        'next': 'next',
        'offset': 'offset',
        'prev': 'prev',
        'total': 'total'
    }

    def __init__(self, event_items=None, href=None, limit=None, next=None, offset=None, prev=None, total=None):  # noqa: E501
        """EventItemSearchResponse - a model defined in Swagger"""  # noqa: E501
        self._event_items = None
        self._href = None
        self._limit = None
        self._next = None
        self._offset = None
        self._prev = None
        self._total = None
        self.discriminator = None
        if event_items is not None:
            self.event_items = event_items
        if href is not None:
            self.href = href
        if limit is not None:
            self.limit = limit
        if next is not None:
            self.next = next
        if offset is not None:
            self.offset = offset
        if prev is not None:
            self.prev = prev
        if total is not None:
            self.total = total

    @property
    def event_items(self):
        """Gets the event_items of this EventItemSearchResponse.  # noqa: E501

        A list of event items that match the search criteria.  # noqa: E501

        :return: The event_items of this EventItemSearchResponse.  # noqa: E501
        :rtype: list[EventItem]
        """
        return self._event_items

    @event_items.setter
    def event_items(self, event_items):
        """Sets the event_items of this EventItemSearchResponse.

        A list of event items that match the search criteria.  # noqa: E501

        :param event_items: The event_items of this EventItemSearchResponse.  # noqa: E501
        :type: list[EventItem]
        """

        self._event_items = event_items

    @property
    def href(self):
        """Gets the href of this EventItemSearchResponse.  # noqa: E501

        The relative path to the current set of results.  # noqa: E501

        :return: The href of this EventItemSearchResponse.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this EventItemSearchResponse.

        The relative path to the current set of results.  # noqa: E501

        :param href: The href of this EventItemSearchResponse.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def limit(self):
        """Gets the limit of this EventItemSearchResponse.  # noqa: E501

        The maximum number of items, from the current result set, returned on a single page. Default: 20  # noqa: E501

        :return: The limit of this EventItemSearchResponse.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this EventItemSearchResponse.

        The maximum number of items, from the current result set, returned on a single page. Default: 20  # noqa: E501

        :param limit: The limit of this EventItemSearchResponse.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def next(self):
        """Gets the next of this EventItemSearchResponse.  # noqa: E501

        The relative path to the next set of results.  # noqa: E501

        :return: The next of this EventItemSearchResponse.  # noqa: E501
        :rtype: str
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this EventItemSearchResponse.

        The relative path to the next set of results.  # noqa: E501

        :param next: The next of this EventItemSearchResponse.  # noqa: E501
        :type: str
        """

        self._next = next

    @property
    def offset(self):
        """Gets the offset of this EventItemSearchResponse.  # noqa: E501

        The number of items that will be skipped in the result set. This is used with the limit field to control the pagination of the output. For example, if the offset is set to 0 and the limit is set to 10, the method will retrieve items 1 through 10 from the list of items returned. If the offset is set to 10 and the limit is set to 10, the method will retrieve items 11 through 20 from the list of items returned. Default: 0  # noqa: E501

        :return: The offset of this EventItemSearchResponse.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this EventItemSearchResponse.

        The number of items that will be skipped in the result set. This is used with the limit field to control the pagination of the output. For example, if the offset is set to 0 and the limit is set to 10, the method will retrieve items 1 through 10 from the list of items returned. If the offset is set to 10 and the limit is set to 10, the method will retrieve items 11 through 20 from the list of items returned. Default: 0  # noqa: E501

        :param offset: The offset of this EventItemSearchResponse.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def prev(self):
        """Gets the prev of this EventItemSearchResponse.  # noqa: E501

        The relative path to the previous set of results.  # noqa: E501

        :return: The prev of this EventItemSearchResponse.  # noqa: E501
        :rtype: str
        """
        return self._prev

    @prev.setter
    def prev(self, prev):
        """Sets the prev of this EventItemSearchResponse.

        The relative path to the previous set of results.  # noqa: E501

        :param prev: The prev of this EventItemSearchResponse.  # noqa: E501
        :type: str
        """

        self._prev = prev

    @property
    def total(self):
        """Gets the total of this EventItemSearchResponse.  # noqa: E501

        The total number of matches for the specified search criteria.  # noqa: E501

        :return: The total of this EventItemSearchResponse.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this EventItemSearchResponse.

        The total number of matches for the specified search criteria.  # noqa: E501

        :param total: The total of this EventItemSearchResponse.  # noqa: E501
        :type: int
        """

        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventItemSearchResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventItemSearchResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Recommendation API

    The <b>Recommendation API</b> returns information that sellers can use to optimize the configuration of their listings on eBay. <br><br>Currently, the API contains a single method, <b>findListingRecommendations</b>. This method provides information that sellers can use to configure Promoted Listings ad campaigns to maximize the visibility of their items in the eBay marketplace.  # noqa: E501

    OpenAPI spec version: 1.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from ..sell_recommendation.api.listing_recommendation_api import ListingRecommendationApi
# import ApiClient
from ..sell_recommendation.api_client import ApiClient
from ..sell_recommendation.configuration import Configuration
# import models into sdk package
from ..sell_recommendation.models.ad import Ad
from ..sell_recommendation.models.bid_percentages import BidPercentages
from ..sell_recommendation.models.error import Error
from ..sell_recommendation.models.error_parameter import ErrorParameter
from ..sell_recommendation.models.find_listing_recommendation_request import FindListingRecommendationRequest
from ..sell_recommendation.models.listing_recommendation import ListingRecommendation
from ..sell_recommendation.models.marketing_recommendation import MarketingRecommendation
from ..sell_recommendation.models.paged_listing_recommendation_collection import PagedListingRecommendationCollection



# coding: utf-8

"""
    Negotiation API

    The <b>Negotiations API</b> gives sellers the ability to proactively send discount offers to buyers who have shown an \"interest\" in their listings.  <br><br>By sending buyers discount offers on listings where they have shown an interest, sellers can increase the velocity of their sales.  <br><br>There are various ways for a buyer to show <i>interest </i> in a listing. For example, if a buyer adds the listing to their <b>Watch</b> list, or if they add the listing to their shopping cart and later abandon the cart, they are deemed to have shown an interest in the listing.  <br><br>In the offers that sellers send, they can discount their listings by either a percentage off the listing price, or they can set a new discounted price that is lower than the original listing price.  <br><br>For details about how seller offers work, see <a href=\"/api-docs/sell/static/marketing/offers-to-buyers.html\" title=\"Selling Integration Guide\">Sending offers to buyers</a>.  # noqa: E501

    OpenAPI spec version: v1.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Offer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_counter_offer': 'bool',
        'buyer': 'User',
        'creation_date': 'str',
        'initiated_by': 'str',
        'last_modified_date': 'str',
        'message': 'str',
        'offer_duration': 'TimeDuration',
        'offered_items': 'list[OfferedItem]',
        'offer_id': 'str',
        'offer_status': 'str',
        'offer_type': 'str',
        'revision': 'str'
    }

    attribute_map = {
        'allow_counter_offer': 'allowCounterOffer',
        'buyer': 'buyer',
        'creation_date': 'creationDate',
        'initiated_by': 'initiatedBy',
        'last_modified_date': 'lastModifiedDate',
        'message': 'message',
        'offer_duration': 'offerDuration',
        'offered_items': 'offeredItems',
        'offer_id': 'offerId',
        'offer_status': 'offerStatus',
        'offer_type': 'offerType',
        'revision': 'revision'
    }

    def __init__(self, allow_counter_offer=None, buyer=None, creation_date=None, initiated_by=None, last_modified_date=None, message=None, offer_duration=None, offered_items=None, offer_id=None, offer_status=None, offer_type=None, revision=None):  # noqa: E501
        """Offer - a model defined in Swagger"""  # noqa: E501
        self._allow_counter_offer = None
        self._buyer = None
        self._creation_date = None
        self._initiated_by = None
        self._last_modified_date = None
        self._message = None
        self._offer_duration = None
        self._offered_items = None
        self._offer_id = None
        self._offer_status = None
        self._offer_type = None
        self._revision = None
        self.discriminator = None
        if allow_counter_offer is not None:
            self.allow_counter_offer = allow_counter_offer
        if buyer is not None:
            self.buyer = buyer
        if creation_date is not None:
            self.creation_date = creation_date
        if initiated_by is not None:
            self.initiated_by = initiated_by
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if message is not None:
            self.message = message
        if offer_duration is not None:
            self.offer_duration = offer_duration
        if offered_items is not None:
            self.offered_items = offered_items
        if offer_id is not None:
            self.offer_id = offer_id
        if offer_status is not None:
            self.offer_status = offer_status
        if offer_type is not None:
            self.offer_type = offer_type
        if revision is not None:
            self.revision = revision

    @property
    def allow_counter_offer(self):
        """Gets the allow_counter_offer of this Offer.  # noqa: E501

        If set to true, the buyer is allowed to make a counter-offer to the seller's offer.  # noqa: E501

        :return: The allow_counter_offer of this Offer.  # noqa: E501
        :rtype: bool
        """
        return self._allow_counter_offer

    @allow_counter_offer.setter
    def allow_counter_offer(self, allow_counter_offer):
        """Sets the allow_counter_offer of this Offer.

        If set to true, the buyer is allowed to make a counter-offer to the seller's offer.  # noqa: E501

        :param allow_counter_offer: The allow_counter_offer of this Offer.  # noqa: E501
        :type: bool
        """

        self._allow_counter_offer = allow_counter_offer

    @property
    def buyer(self):
        """Gets the buyer of this Offer.  # noqa: E501


        :return: The buyer of this Offer.  # noqa: E501
        :rtype: User
        """
        return self._buyer

    @buyer.setter
    def buyer(self, buyer):
        """Sets the buyer of this Offer.


        :param buyer: The buyer of this Offer.  # noqa: E501
        :type: User
        """

        self._buyer = buyer

    @property
    def creation_date(self):
        """Gets the creation_date of this Offer.  # noqa: E501

        The date and time when the seller's offer was created. The returned timestamp is formatted as an ISO 8601 string, which is based on the 24-hour Coordinated Universal Time (UTC) clock. Format: [YYYY]-[MM]-[DD]T[hh]:[mm]:[ss].[sss]Z Example: 2018-08-20T07:09:00.000Z  # noqa: E501

        :return: The creation_date of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this Offer.

        The date and time when the seller's offer was created. The returned timestamp is formatted as an ISO 8601 string, which is based on the 24-hour Coordinated Universal Time (UTC) clock. Format: [YYYY]-[MM]-[DD]T[hh]:[mm]:[ss].[sss]Z Example: 2018-08-20T07:09:00.000Z  # noqa: E501

        :param creation_date: The creation_date of this Offer.  # noqa: E501
        :type: str
        """

        self._creation_date = creation_date

    @property
    def initiated_by(self):
        """Gets the initiated_by of this Offer.  # noqa: E501

        The eBay UserName of the user (seller) who initiated the offer.  # noqa: E501

        :return: The initiated_by of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._initiated_by

    @initiated_by.setter
    def initiated_by(self, initiated_by):
        """Sets the initiated_by of this Offer.

        The eBay UserName of the user (seller) who initiated the offer.  # noqa: E501

        :param initiated_by: The initiated_by of this Offer.  # noqa: E501
        :type: str
        """

        self._initiated_by = initiated_by

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this Offer.  # noqa: E501

        The date and time when the offer was last modified. The returned timestamp is formatted as an ISO 8601 string.  # noqa: E501

        :return: The last_modified_date of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this Offer.

        The date and time when the offer was last modified. The returned timestamp is formatted as an ISO 8601 string.  # noqa: E501

        :param last_modified_date: The last_modified_date of this Offer.  # noqa: E501
        :type: str
        """

        self._last_modified_date = last_modified_date

    @property
    def message(self):
        """Gets the message of this Offer.  # noqa: E501

        A seller-defined message related to the offer being made. This message is sent to the list of &quot;interested&quot; buyers along with the offer message from eBay.  # noqa: E501

        :return: The message of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Offer.

        A seller-defined message related to the offer being made. This message is sent to the list of &quot;interested&quot; buyers along with the offer message from eBay.  # noqa: E501

        :param message: The message of this Offer.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def offer_duration(self):
        """Gets the offer_duration of this Offer.  # noqa: E501


        :return: The offer_duration of this Offer.  # noqa: E501
        :rtype: TimeDuration
        """
        return self._offer_duration

    @offer_duration.setter
    def offer_duration(self, offer_duration):
        """Sets the offer_duration of this Offer.


        :param offer_duration: The offer_duration of this Offer.  # noqa: E501
        :type: TimeDuration
        """

        self._offer_duration = offer_duration

    @property
    def offered_items(self):
        """Gets the offered_items of this Offer.  # noqa: E501

        The list of items associated with the offer. Currently, the offer list is restricted to a single offer.  # noqa: E501

        :return: The offered_items of this Offer.  # noqa: E501
        :rtype: list[OfferedItem]
        """
        return self._offered_items

    @offered_items.setter
    def offered_items(self, offered_items):
        """Sets the offered_items of this Offer.

        The list of items associated with the offer. Currently, the offer list is restricted to a single offer.  # noqa: E501

        :param offered_items: The offered_items of this Offer.  # noqa: E501
        :type: list[OfferedItem]
        """

        self._offered_items = offered_items

    @property
    def offer_id(self):
        """Gets the offer_id of this Offer.  # noqa: E501

        A unique eBay-assigned identifier for the offer.  # noqa: E501

        :return: The offer_id of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._offer_id

    @offer_id.setter
    def offer_id(self, offer_id):
        """Sets the offer_id of this Offer.

        A unique eBay-assigned identifier for the offer.  # noqa: E501

        :param offer_id: The offer_id of this Offer.  # noqa: E501
        :type: str
        """

        self._offer_id = offer_id

    @property
    def offer_status(self):
        """Gets the offer_status of this Offer.  # noqa: E501

        The current state, or status, of an offer. Status states include PENDING, COUNTERED, ACCEPTED, and DECLINED. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/negotiation/types/api:OfferStatusEnum'>eBay API documentation</a>  # noqa: E501

        :return: The offer_status of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._offer_status

    @offer_status.setter
    def offer_status(self, offer_status):
        """Sets the offer_status of this Offer.

        The current state, or status, of an offer. Status states include PENDING, COUNTERED, ACCEPTED, and DECLINED. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/negotiation/types/api:OfferStatusEnum'>eBay API documentation</a>  # noqa: E501

        :param offer_status: The offer_status of this Offer.  # noqa: E501
        :type: str
        """

        self._offer_status = offer_status

    @property
    def offer_type(self):
        """Gets the offer_type of this Offer.  # noqa: E501

        The type of offer being made. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/negotiation/types/api:OfferTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The offer_type of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._offer_type

    @offer_type.setter
    def offer_type(self, offer_type):
        """Sets the offer_type of this Offer.

        The type of offer being made. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/negotiation/types/api:OfferTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param offer_type: The offer_type of this Offer.  # noqa: E501
        :type: str
        """

        self._offer_type = offer_type

    @property
    def revision(self):
        """Gets the revision of this Offer.  # noqa: E501

        A unique, eBay-assigned ID for the revision of the offer.  # noqa: E501

        :return: The revision of this Offer.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Offer.

        A unique, eBay-assigned ID for the revision of the offer.  # noqa: E501

        :param revision: The revision of this Offer.  # noqa: E501
        :type: str
        """

        self._revision = revision

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Offer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Offer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
